@@ -87,7 +87,6 @@ $rules = [
     'single_quote' => true,
     'space_after_semicolon' => true,
     'standardize_not_equals' => true,
-    'statement_indentation' => false,
     'ternary_operator_spaces' => true,
     'trailing_comma_in_multiline' => true,
     'trim_array_spaces' => true,
@@ -101,13 +100,13 @@ $rules = [
 ];
 
 return (new Config())->setRules($rules)
-             ->setFinder(
-                 Finder::create()
-                    ->in(__DIR__)
-                    ->notPath([
-                        'src/Carbon/Doctrine/DateTimeImmutableType.php',
-                        'src/Carbon/Doctrine/DateTimeType.php',
-                    ])
-             )
-             ->setUsingCache(true)
-             ->setRiskyAllowed(true);
+    ->setFinder(
+        Finder::create()
+            ->in(__DIR__)
+            ->notPath([
+                'src/Carbon/Doctrine/DateTimeImmutableType.php',
+                'src/Carbon/Doctrine/DateTimeType.php',
+            ]),
+    )
+    ->setUsingCache(true)
+    ->setRiskyAllowed(true);
