@@ -18,59 +18,44 @@ use Carbon\CarbonImmutable;
 use Carbon\CarbonInterface;
 use Carbon\CarbonInterval;
 use Carbon\CarbonPeriod;
+use Carbon\CarbonPeriodImmutable;
 use Carbon\CarbonTimeZone;
 use Carbon\Translator;
 use Closure;
 use DateTime;
+use ErrorException;
 use PHPUnit\Framework\TestCase;
+use PHPUnit\Runner\Version;
 use ReflectionProperty;
 use Tests\PHPUnit\AssertObjectHasPropertyTrait;
 use Throwable;
 
 /**
- * @SuppressWarnings(PHPMD.NumberOfChildren)
+ * @SuppressWarnings(NumberOfChildren)
  */
 abstract class AbstractTestCase extends TestCase
 {
     use AssertObjectHasPropertyTrait;
 
-    /**
-     * @var \Carbon\Carbon
-     */
-    protected $now;
+    private ?string $saveTz = null;
+    protected ?Carbon $now = null;
+    protected ?CarbonImmutable $immutableNow = null;
+    protected bool $oldNow = false;
+    protected bool $oldImmutableNow = false;
 
-    /**
-     * @var \Carbon\CarbonImmutable
-     */
-    protected $immutableNow;
+    /** @var class-string<CarbonPeriod> */
+    protected static string $periodClass = CarbonPeriod::class;
+    protected int $initialOptions = 0;
 
-    /**
-     * @var bool
-     */
-    protected $oldNow = false;
-
-    /**
-     * @var bool
-     */
-    protected $oldImmutableNow = false;
-
-    /**
-     * @var string
-     */
-    private $saveTz;
-
-    /**
-     * @var class-string<CarbonPeriod>
-     */
-    protected $periodClass = CarbonPeriod::class;
-
-    protected function getTimestamp()
+    protected function getTimestamp(): int
     {
         return (new DateTime())->getTimestamp();
     }
 
     protected function setUp(): void
     {
+        $this->initialOptions = static::$periodClass === CarbonPeriodImmutable::class ? CarbonPeriod::IMMUTABLE : 0;
+
         //save current timezone
         $this->saveTz = date_default_timezone_get();
 
@@ -116,7 +101,7 @@ abstract class AbstractTestCase extends TestCase
         $translator->resetMessages();
     }
 
-    public function assertCarbon(CarbonInterface $d, $year, $month, $day, $hour = null, $minute = null, $second = null, $micro = null)
+    public function assertCarbon(CarbonInterface $d, $year, $month, $day, $hour = null, $minute = null, $second = null, $micro = null): void
     {
         $expected = [
             'years' => $year,
@@ -153,7 +138,7 @@ abstract class AbstractTestCase extends TestCase
         $this->assertSame($expected, $actual);
     }
 
-    public function assertCarbonTime(CarbonInterface $d, $hour = null, $minute = null, $second = null, $micro = null)
+    public function assertCarbonTime(CarbonInterface $d, $hour = null, $minute = null, $second = null, $micro = null): void
     {
         $actual = [];
 
@@ -185,12 +170,12 @@ abstract class AbstractTestCase extends TestCase
     /**
      * @phpstan-assert CarbonInterface $d
      */
-    public function assertInstanceOfCarbon($d)
+    public function assertInstanceOfCarbon($d): void
     {
         $this->assertInstanceOf(CarbonInterface::class, $d);
     }
 
-    public function assertCarbonInterval(CarbonInterval $ci, $years, $months = null, $days = null, $hours = null, $minutes = null, $seconds = null, $microseconds = null, $inverted = null)
+    public function assertCarbonInterval(CarbonInterval $ci, $years, $months = null, $days = null, $hours = null, $minutes = null, $seconds = null, $microseconds = null, $inverted = null): void
     {
         $actual = ['years' => $ci->years];
 
@@ -236,12 +221,12 @@ abstract class AbstractTestCase extends TestCase
     /**
      * @phpstan-assert CarbonInterval $d
      */
-    public function assertInstanceOfCarbonInterval($d)
+    public function assertInstanceOfCarbonInterval($d): void
     {
         $this->assertInstanceOf(CarbonInterval::class, $d);
     }
 
-    public function wrapWithTestNow(Closure $func, ?CarbonInterface $dt = null)
+    public function wrapWithTestNow(Closure $func, ?CarbonInterface $dt = null): void
     {
         $test = Carbon::getTestNow();
         $immutableTest = CarbonImmutable::getTestNow();
@@ -253,12 +238,12 @@ abstract class AbstractTestCase extends TestCase
         CarbonImmutable::setTestNowAndTimezone($immutableTest);
     }
 
-    public function wrapWithNonDstDate(Closure $func)
+    public function wrapWithNonDstDate(Closure $func): void
     {
         $this->wrapWithTestNow($func, Carbon::now()->startOfYear());
     }
 
-    public function wrapWithUtf8LcTimeLocale($locale, Closure $func)
+    public function wrapWithUtf8LcTimeLocale($locale, Closure $func): void
     {
         $currentLocale = setlocale(LC_TIME, '0');
         $locales = ["$locale.UTF-8", "$locale.utf8"];
@@ -275,18 +260,28 @@ abstract class AbstractTestCase extends TestCase
             $this->markTestSkipped("UTF-8 test need $locale.UTF-8 (a locale with accents).");
         }
 
-        $exception = null;
-
         try {
             $func();
-        } catch (Throwable $e) {
-            $exception = $e;
+        } finally {
+            setlocale(LC_TIME, $currentLocale);
         }
+    }
 
-        setlocale(LC_TIME, $currentLocale);
+    public function withErrorAsException(Closure $func): void
+    {
+        $previous = set_error_handler(static function (int $code, string $message, string $file, int $line) {
+            throw new ErrorException($message, $code, $code, $file, $line);
+        });
 
-        if ($exception) {
-            throw $exception;
+        $errorReporting = error_reporting();
+
+        try {
+            error_reporting(E_ALL);
+
+            $func();
+        } finally {
+            error_reporting($errorReporting);
+            restore_error_handler();
         }
     }
 
@@ -314,13 +309,12 @@ abstract class AbstractTestCase extends TestCase
         return $result;
     }
 
-    protected function areSameLocales($a, $b)
+    protected function areSameLocales($a, $b): bool
     {
         static $aliases = null;
 
         if ($aliases === null) {
             $property = new ReflectionProperty(Translator::class, 'aliases');
-            $property->setAccessible(true);
             $aliases = $property->getValue(Translator::get());
         }
 
@@ -344,4 +338,125 @@ abstract class AbstractTestCase extends TestCase
 
         throw $firstError;
     }
+
+    protected function assertPeriodOptions(int $options, CarbonPeriod $period): void
+    {
+        $this->assertSame($this->initialOptions | $options, $period->getOptions());
+    }
+
+    protected function assertVeryClose(mixed $expected, mixed $actual, string $message = ''): void
+    {
+        $this->assertEqualsWithDelta(
+            $expected,
+            $actual,
+            0.000000000000001,
+            $message,
+        );
+    }
+
+    protected function assertSameIntervals(CarbonInterval $expected, CarbonInterval $actual, int $microsecondApproximation = 0): void
+    {
+        if (
+            $expected->microseconds !== $actual->microseconds
+            && $microsecondApproximation > 0
+            && $actual->microseconds >= $expected->microseconds - $microsecondApproximation
+            && $actual->microseconds <= $expected->microseconds + $microsecondApproximation
+        ) {
+            $actual->optimize();
+            $expected->optimize();
+            $expected->microseconds = $actual->microseconds;
+        }
+
+        $expectedProperties = $this->fetchProperties($expected);
+        $actualProperties = $this->fetchProperties($actual);
+
+        if (
+            isset($expectedProperties['f'], $actualProperties['f'])
+            && $expectedProperties['f'] !== $actualProperties['f']
+            && (abs($expectedProperties['f'] - $actualProperties['f']) * 1_000_000) < ($microsecondApproximation * 1.2)
+        ) {
+            $expectedProperties['f'] = $actualProperties['f'];
+        }
+
+        if (PHP_VERSION < 8.2) {
+            unset($expectedProperties['days']);
+            unset($actualProperties['days']);
+        }
+
+        if (
+            isset($expectedProperties['rawInterval'], $actualProperties['rawInterval'])
+            && $expectedProperties['rawInterval']->f !== $actualProperties['rawInterval']->f
+            && $microsecondApproximation > 0
+            && $actualProperties['rawInterval']->f >= $expectedProperties['rawInterval']->f - $microsecondApproximation
+            && $actualProperties['rawInterval']->f <= $expectedProperties['rawInterval']->f + $microsecondApproximation
+        ) {
+            unset($expectedProperties['rawInterval']);
+            unset($expectedProperties['originalInput']);
+            unset($actualProperties['rawInterval']);
+            unset($actualProperties['originalInput']);
+        }
+
+        if (Version::id() >= 12 && isset($expectedProperties['localTranslator'])) {
+            /** @var Translator $expectedTranslator */
+            $expectedTranslator = $expectedProperties['localTranslator'];
+            /** @var Translator $actualTranslator */
+            $actualTranslator = $actualProperties['localTranslator'] ?? null;
+            $this->assertInstanceOf(Translator::class, $actualTranslator);
+            $this->assertSame($expectedTranslator->getLocale(), $actualTranslator->getLocale());
+            $this->assertSameWithClosures($expectedTranslator->getMessages(), $actualTranslator->getMessages());
+            unset($expectedProperties['localTranslator'], $actualProperties['localTranslator']);
+        }
+
+        $this->assertEquals($expectedProperties, $actualProperties);
+    }
+
+    protected function assertSameWithClosures(array $expected, array $actual): void
+    {
+        $expected = $this->acceptClosuresFrom($expected, $actual);
+
+        $this->assertSame($expected, $actual);
+    }
+
+    private function acceptClosuresFrom(array $destination, array $source): array
+    {
+        foreach ($source as $key => $value) {
+            if (\is_array($value) && \is_array($destination[$key])) {
+                $destination[$key] = $this->acceptClosuresFrom($destination[$key], $value);
+
+                continue;
+            }
+
+            if (($value instanceof Closure) && ($destination[$key] instanceof Closure)) {
+                if ($destination[$key] !== $value && $this->captureVarDump($value) === $this->captureVarDump($destination[$key])) {
+                    $destination[$key] = $value;
+                }
+            }
+        }
+
+        return $destination;
+    }
+
+    /** @SuppressWarnings(DevelopmentCodeFragment) */
+    private function captureVarDump(mixed $value): string
+    {
+        ob_start();
+        var_dump($value);
+        $content = ob_get_contents();
+        ob_end_clean();
+
+        return preg_replace('/(Closure.*)#\d+(\s)/', '$1$2', "$content");
+    }
+
+    private function fetchProperties(object $object): array
+    {
+        $properties = (array) $object;
+
+        return array_combine(
+            array_map(
+                static fn (string $property): string => preg_replace('/^\0\*\0/', '', $property),
+                array_keys($properties),
+            ),
+            $properties,
+        );
+    }
 }
