@@ -69,7 +69,7 @@ class CreateFromTimeTest extends AbstractTestCase
     public function testCreateFromTimeGreaterThan99()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'second must be between 0 and 99, 100 given'
+            'second must be between 0 and 99, 100 given',
         ));
 
         Carbon::createFromTime(23, 5, 100);
