@@ -23,16 +23,16 @@ final class DumpCarbon extends Carbon
     private $formatBroken = false;
 
     /**
-     * @SuppressWarnings(PHPMD.DevelopmentCodeFragment)
+     * @SuppressWarnings(DevelopmentCodeFragment)
      */
-    public function __construct($time = null, $tz = null)
+    public function __construct($time = null, $timezone = null)
     {
         ob_start();
         var_dump($this);
         $this->dump = ob_get_contents() ?: '';
         ob_end_clean();
 
-        parent::__construct($time, $tz);
+        parent::__construct($time, $timezone);
     }
 
     public function getDump(): string
@@ -45,7 +45,7 @@ final class DumpCarbon extends Carbon
         $this->formatBroken = true;
     }
 
-    public function format($format)
+    public function format(string $format): string
     {
         if ($this->formatBroken) {
             throw new Exception('Broken');
