@@ -1,4 +1,5 @@
 <?php
+
 declare(strict_types=1);
 
 /**
@@ -9,13 +10,14 @@ declare(strict_types=1);
  * For the full copyright and license information, please view the LICENSE
  * file that was distributed with this source code.
  */
+
 namespace Tests\Carbon\Fixtures;
 
 use Carbon\CarbonInterface;
 
 class Mixin
 {
-    public $timezone = null;
+    public $timezone;
 
     public function __construct($timezone)
     {
