@@ -14,32 +14,25 @@ declare(strict_types=1);
 namespace Tests\Carbon;
 
 use Carbon\Carbon;
+use Carbon\CarbonInterface;
 use Carbon\CarbonInterval;
-use Carbon\Exceptions\NotLocaleAwareException;
 use Carbon\Language;
 use Carbon\Translator;
-use Generator;
 use InvalidArgumentException;
+use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
+use PHPUnit\Framework\Attributes\TestWith;
 use Symfony\Component\Translation\IdentityTranslator;
 use Symfony\Component\Translation\Loader\ArrayLoader;
 use Symfony\Component\Translation\MessageCatalogue;
-use Symfony\Component\Translation\MessageSelector;
 use Symfony\Component\Translation\Translator as SymfonyTranslator;
-use Symfony\Component\Translation\TranslatorInterface;
 use Tests\AbstractTestCase;
 use Tests\Carbon\Fixtures\MyCarbon;
+use Tests\Carbon\Fixtures\NoLocaleTranslator;
 
-/**
- * @group localization
- */
+#[Group('localization')]
 class LocalizationTest extends AbstractTestCase
 {
-    protected function tearDown(): void
-    {
-        parent::tearDown();
-        Carbon::setLocale('en');
-    }
-
     public function testGetTranslator()
     {
         /** @var Translator $t */
@@ -172,166 +165,158 @@ class LocalizationTest extends AbstractTestCase
     /**
      * @see \Tests\Carbon\LocalizationTest::testSetLocale
      * @see \Tests\Carbon\LocalizationTest::testSetTranslator
-     *
-     * @return \Generator
      */
-    public static function dataForLocales(): Generator
+    public static function dataForLocales(): array
     {
-        yield ['af'];
-        yield ['ar'];
-        yield ['ar_DZ'];
-        yield ['ar_KW'];
-        yield ['ar_LY'];
-        yield ['ar_MA'];
-        yield ['ar_SA'];
-        yield ['ar_Shakl'];
-        yield ['ar_TN'];
-        yield ['az'];
-        yield ['be'];
-        yield ['bg'];
-        yield ['bm'];
-        yield ['bn'];
-        yield ['bo'];
-        yield ['br'];
-        yield ['bs'];
-        yield ['bs_BA'];
-        yield ['ca'];
-        yield ['cs'];
-        yield ['cv'];
-        yield ['cy'];
-        yield ['da'];
-        yield ['de'];
-        yield ['de_AT'];
-        yield ['de_CH'];
-        yield ['dv'];
-        yield ['dv_MV'];
-        yield ['el'];
-        yield ['en'];
-        yield ['en_AU'];
-        yield ['en_CA'];
-        yield ['en_GB'];
-        yield ['en_IE'];
-        yield ['en_IL'];
-        yield ['en_NZ'];
-        yield ['eo'];
-        yield ['es'];
-        yield ['es_DO'];
-        yield ['es_US'];
-        yield ['et'];
-        yield ['eu'];
-        yield ['fa'];
-        yield ['fi'];
-        yield ['fo'];
-        yield ['fr'];
-        yield ['fr_CA'];
-        yield ['fr_CH'];
-        yield ['fy'];
-        yield ['gd'];
-        yield ['gl'];
-        yield ['gom_Latn'];
-        yield ['gu'];
-        yield ['he'];
-        yield ['hi'];
-        yield ['hr'];
-        yield ['hu'];
-        yield ['hy'];
-        yield ['hy_AM'];
-        yield ['id'];
-        yield ['is'];
-        yield ['it'];
-        yield ['ja'];
-        yield ['jv'];
-        yield ['ka'];
-        yield ['kk'];
-        yield ['km'];
-        yield ['kn'];
-        yield ['ko'];
-        yield ['ku'];
-        yield ['ky'];
-        yield ['lb'];
-        yield ['lo'];
-        yield ['lt'];
-        yield ['lv'];
-        yield ['me'];
-        yield ['mi'];
-        yield ['mk'];
-        yield ['ml'];
-        yield ['mn'];
-        yield ['mr'];
-        yield ['ms'];
-        yield ['ms_MY'];
-        yield ['mt'];
-        yield ['my'];
-        yield ['nb'];
-        yield ['ne'];
-        yield ['nl'];
-        yield ['nl_BE'];
-        yield ['nn'];
-        yield ['no'];
-        yield ['oc'];
-        yield ['pa_IN'];
-        yield ['pl'];
-        yield ['ps'];
-        yield ['pt'];
-        yield ['pt_BR'];
-        yield ['ro'];
-        yield ['ru'];
-        yield ['sd'];
-        yield ['se'];
-        yield ['sh'];
-        yield ['si'];
-        yield ['sk'];
-        yield ['sl'];
-        yield ['sq'];
-        yield ['sr'];
-        yield ['sr_Cyrl'];
-        yield ['sr_Cyrl_ME'];
-        yield ['sr_Latn_ME'];
-        yield ['sr_ME'];
-        yield ['ss'];
-        yield ['sv'];
-        yield ['sw'];
-        yield ['ta'];
-        yield ['te'];
-        yield ['tet'];
-        yield ['tg'];
-        yield ['th'];
-        yield ['tl_PH'];
-        yield ['tlh'];
-        yield ['tr'];
-        yield ['tzl'];
-        yield ['tzm'];
-        yield ['tzm_Latn'];
-        yield ['ug_CN'];
-        yield ['uk'];
-        yield ['ur'];
-        yield ['uz'];
-        yield ['uz_Latn'];
-        yield ['vi'];
-        yield ['yo'];
-        yield ['zh'];
-        yield ['zh_CN'];
-        yield ['zh_HK'];
-        yield ['zh_TW'];
+        return [
+            'af' => ['af'],
+            'ar' => ['ar'],
+            'ar_DZ' => ['ar_DZ'],
+            'ar_KW' => ['ar_KW'],
+            'ar_LY' => ['ar_LY'],
+            'ar_MA' => ['ar_MA'],
+            'ar_SA' => ['ar_SA'],
+            'ar_Shakl' => ['ar_Shakl'],
+            'ar_TN' => ['ar_TN'],
+            'az' => ['az'],
+            'be' => ['be'],
+            'bg' => ['bg'],
+            'bm' => ['bm'],
+            'bn' => ['bn'],
+            'bo' => ['bo'],
+            'br' => ['br'],
+            'bs' => ['bs'],
+            'bs_BA' => ['bs_BA'],
+            'ca' => ['ca'],
+            'cs' => ['cs'],
+            'cv' => ['cv'],
+            'cy' => ['cy'],
+            'da' => ['da'],
+            'de' => ['de'],
+            'de_AT' => ['de_AT'],
+            'de_CH' => ['de_CH'],
+            'dv' => ['dv'],
+            'dv_MV' => ['dv_MV'],
+            'el' => ['el'],
+            'en' => ['en'],
+            'en_AU' => ['en_AU'],
+            'en_CA' => ['en_CA'],
+            'en_GB' => ['en_GB'],
+            'en_IE' => ['en_IE'],
+            'en_IL' => ['en_IL'],
+            'en_NZ' => ['en_NZ'],
+            'eo' => ['eo'],
+            'es' => ['es'],
+            'es_DO' => ['es_DO'],
+            'es_US' => ['es_US'],
+            'et' => ['et'],
+            'eu' => ['eu'],
+            'fa' => ['fa'],
+            'fi' => ['fi'],
+            'fo' => ['fo'],
+            'fr' => ['fr'],
+            'fr_CA' => ['fr_CA'],
+            'fr_CH' => ['fr_CH'],
+            'fy' => ['fy'],
+            'gd' => ['gd'],
+            'gl' => ['gl'],
+            'gom_Latn' => ['gom_Latn'],
+            'gu' => ['gu'],
+            'he' => ['he'],
+            'hi' => ['hi'],
+            'hr' => ['hr'],
+            'hu' => ['hu'],
+            'hy' => ['hy'],
+            'hy_AM' => ['hy_AM'],
+            'id' => ['id'],
+            'is' => ['is'],
+            'it' => ['it'],
+            'ja' => ['ja'],
+            'jv' => ['jv'],
+            'ka' => ['ka'],
+            'kk' => ['kk'],
+            'km' => ['km'],
+            'kn' => ['kn'],
+            'ko' => ['ko'],
+            'ku' => ['ku'],
+            'ky' => ['ky'],
+            'lb' => ['lb'],
+            'lo' => ['lo'],
+            'lt' => ['lt'],
+            'lv' => ['lv'],
+            'me' => ['me'],
+            'mi' => ['mi'],
+            'mk' => ['mk'],
+            'ml' => ['ml'],
+            'mn' => ['mn'],
+            'mr' => ['mr'],
+            'ms' => ['ms'],
+            'ms_MY' => ['ms_MY'],
+            'mt' => ['mt'],
+            'my' => ['my'],
+            'nb' => ['nb'],
+            'ne' => ['ne'],
+            'nl' => ['nl'],
+            'nl_BE' => ['nl_BE'],
+            'nn' => ['nn'],
+            'no' => ['no'],
+            'oc' => ['oc'],
+            'pa_IN' => ['pa_IN'],
+            'pl' => ['pl'],
+            'ps' => ['ps'],
+            'pt' => ['pt'],
+            'pt_BR' => ['pt_BR'],
+            'ro' => ['ro'],
+            'ru' => ['ru'],
+            'sd' => ['sd'],
+            'se' => ['se'],
+            'sh' => ['sh'],
+            'si' => ['si'],
+            'sk' => ['sk'],
+            'sl' => ['sl'],
+            'sq' => ['sq'],
+            'sr' => ['sr'],
+            'sr_Cyrl' => ['sr_Cyrl'],
+            'sr_Cyrl_ME' => ['sr_Cyrl_ME'],
+            'sr_Latn_ME' => ['sr_Latn_ME'],
+            'sr_ME' => ['sr_ME'],
+            'ss' => ['ss'],
+            'sv' => ['sv'],
+            'sw' => ['sw'],
+            'ta' => ['ta'],
+            'te' => ['te'],
+            'tet' => ['tet'],
+            'tg' => ['tg'],
+            'th' => ['th'],
+            'tl_PH' => ['tl_PH'],
+            'tlh' => ['tlh'],
+            'tr' => ['tr'],
+            'tzl' => ['tzl'],
+            'tzm' => ['tzm'],
+            'tzm_Latn' => ['tzm_Latn'],
+            'ug_CN' => ['ug_CN'],
+            'uk' => ['uk'],
+            'ur' => ['ur'],
+            'uz' => ['uz'],
+            'uz_Latn' => ['uz_Latn'],
+            'vi' => ['vi'],
+            'yo' => ['yo'],
+            'zh' => ['zh'],
+            'zh_CN' => ['zh_CN'],
+            'zh_HK' => ['zh_HK'],
+            'zh_TW' => ['zh_TW'],
+        ];
     }
 
-    /**
-     * @dataProvider \Tests\Carbon\LocalizationTest::dataForLocales
-     *
-     * @param string $locale
-     */
-    public function testSetLocale($locale)
+    #[DataProvider('dataForLocales')]
+    public function testSetLocale(string $locale)
     {
-        $this->assertTrue(Carbon::setLocale($locale));
+        Carbon::setLocale($locale);
         $this->assertTrue($this->areSameLocales($locale, Carbon::getLocale()));
     }
 
-    /**
-     * @dataProvider \Tests\Carbon\LocalizationTest::dataForLocales
-     *
-     * @param string $locale
-     */
-    public function testSetTranslator($locale)
+    #[DataProvider('dataForLocales')]
+    public function testSetTranslator(string $locale)
     {
         $ori = Carbon::getTranslator();
         $t = new Translator($locale);
@@ -348,44 +333,42 @@ class LocalizationTest extends AbstractTestCase
 
     public function testSetLocaleWithKnownLocale()
     {
-        $this->assertTrue(Carbon::setLocale('fr'));
+        Carbon::setLocale('fr');
+
+        $this->assertSame('fr', Carbon::getLocale());
     }
 
-    /**
-     * @see \Tests\Carbon\LocalizationTest::testSetLocaleWithMalformedLocale
-     *
-     * @return \Generator
-     */
-    public static function dataForTestSetLocaleWithMalformedLocale(): Generator
+    #[TestWith(['DE'])]
+    #[TestWith(['pt-BR'])]
+    #[TestWith(['pt-br'])]
+    #[TestWith(['PT-br'])]
+    #[TestWith(['PT-BR'])]
+    #[TestWith(['pt_br'])]
+    #[TestWith(['PT_br'])]
+    #[TestWith(['PT_BR'])]
+    public function testSetLocaleWithMalformedLocale(string $malformedLocale)
     {
-        yield ['DE'];
-        yield ['pt-BR'];
-        yield ['pt-br'];
-        yield ['PT-br'];
-        yield ['PT-BR'];
-        yield ['pt_br'];
-        yield ['PT_br'];
-        yield ['PT_BR'];
-    }
+        Carbon::setLocale($malformedLocale);
+        $split = preg_split('/[-_]/', $malformedLocale);
 
-    /**
-     * @dataProvider \Tests\Carbon\LocalizationTest::dataForTestSetLocaleWithMalformedLocale
-     *
-     * @param string $malformedLocale
-     */
-    public function testSetLocaleWithMalformedLocale($malformedLocale)
-    {
-        $this->assertTrue(Carbon::setLocale($malformedLocale));
+        $this->assertSame(
+            strtolower($split[0]).(\count($split) === 1 ? '' : '_'.strtoupper($split[1])),
+            Carbon::getLocale(),
+        );
     }
 
     public function testSetLocaleWithNonExistingLocale()
     {
-        $this->assertFalse(Carbon::setLocale('pt-XX'));
+        Carbon::setLocale('pt-XX');
+
+        $this->assertSame('pt', Carbon::getLocale());
     }
 
     public function testSetLocaleWithUnknownLocale()
     {
-        $this->assertFalse(Carbon::setLocale('zz'));
+        Carbon::setLocale('zz');
+
+        $this->assertSame('en', Carbon::getLocale());
     }
 
     public function testCustomTranslation()
@@ -443,7 +426,8 @@ class LocalizationTest extends AbstractTestCase
             'day' => '1 boring day|%count% boring days',
         ];
 
-        $this->assertTrue(Carbon::setLocale('en'));
+        Carbon::setLocale('en');
+        $this->assertSame('en', Carbon::getLocale());
         /** @var Translator $translator */
         $translator = Carbon::getTranslator();
         $translator->setMessages('en', $enBoring);
@@ -470,7 +454,8 @@ class LocalizationTest extends AbstractTestCase
         $this->assertArrayHasKey('en_Boring', $messages);
         $this->assertSame($enBoring, $messages['en_Boring']);
 
-        $this->assertTrue(Carbon::setLocale('en_Boring'));
+        Carbon::setLocale('en_Boring');
+        $this->assertSame('en_Boring', Carbon::getLocale());
 
         $diff = Carbon::create(2018, 1, 1, 0, 0, 0)
             ->diffForHumans(Carbon::create(2018, 1, 4, 4, 0, 0), true, false, 2);
@@ -478,16 +463,56 @@ class LocalizationTest extends AbstractTestCase
         // en_Boring inherit en because it starts with "en", see symfony-translation behavior
         $this->assertSame('3 boring days 4 hours', $diff);
 
+        Carbon::setLocale('en');
+
+        $diff = Carbon::parse('2018-01-01')
+            ->diffForHumans('2018-01-04 04:00', [
+                'syntax' => CarbonInterface::DIFF_ABSOLUTE,
+                'parts' => 2,
+                'locale' => 'de',
+            ]);
+
+        $this->assertSame('3 Tage 4 Stunden', $diff);
+
         $translator->resetMessages();
 
+        $diff = Carbon::parse('2018-01-01')
+            ->diffForHumans('2018-01-04 04:00', [
+                'syntax' => CarbonInterface::DIFF_ABSOLUTE,
+                'parts' => 2,
+                'locale' => 'de',
+            ]);
+
+        $this->assertSame('3 Tage 4 Stunden', $diff);
+
         $this->assertSame([], $translator->getMessages());
 
-        $this->assertTrue(Carbon::setLocale('en'));
+        $this->assertSame('en', Carbon::getLocale());
+    }
+
+    public function testLocaleOption()
+    {
+        $translator = Translator::get('en_Boring');
+        $translator->setTranslations([
+            'day' => ':count boring day|:count boring days',
+        ]);
+
+        $diff = Carbon::parse('2018-01-01')
+            ->diffForHumans('2018-01-04 04:00', [
+                'syntax' => CarbonInterface::DIFF_ABSOLUTE,
+                'parts' => 2,
+                'locale' => 'en_Boring',
+            ]);
+
+        $translator->setLocale('en');
+        $translator->resetMessages();
+
+        $this->assertSame('3 boring days 4 hours', $diff);
     }
 
     public function testCustomWeekStart()
     {
-        $this->assertTrue(Carbon::setLocale('ru'));
+        Carbon::setLocale('ru');
 
         /** @var Translator $translator */
         $translator = Carbon::getTranslator();
@@ -512,7 +537,7 @@ class LocalizationTest extends AbstractTestCase
 
         $translator->resetMessages('ru');
 
-        $this->assertTrue(Carbon::setLocale('en'));
+        Carbon::setLocale('en');
     }
 
     public function testAddAndRemoveDirectory()
@@ -526,24 +551,24 @@ class LocalizationTest extends AbstractTestCase
         $translator = Carbon::getTranslator();
         Carbon::setLocale('en');
 
-        $this->assertFalse(Carbon::setLocale('foo'));
+        Carbon::setLocale('foo');
         $this->assertSame('Saturday', Carbon::parse('2018-07-07 00:00:00')->isoFormat('dddd'));
 
         $translator->addDirectory($directory);
 
-        $this->assertTrue(Carbon::setLocale('foo'));
+        Carbon::setLocale('foo');
         $this->assertSame('samedi', Carbon::parse('2018-07-07 00:00:00')->isoFormat('dddd'));
 
         Carbon::setLocale('en');
         $translator->removeDirectory($directory);
 
-        $this->assertFalse(Carbon::setLocale('bar'));
+        Carbon::setLocale('bar');
         $this->assertSame('Saturday', Carbon::parse('2018-07-07 00:00:00')->isoFormat('dddd'));
 
-        $this->assertTrue(Carbon::setLocale('foo'));
+        Carbon::setLocale('foo');
         $this->assertSame('samedi', Carbon::parse('2018-07-07 00:00:00')->isoFormat('dddd'));
 
-        $this->assertTrue(Carbon::setLocale('en'));
+        Carbon::setLocale('en');
     }
 
     public function testLocaleHasShortUnits()
@@ -696,28 +721,6 @@ class LocalizationTest extends AbstractTestCase
         $this->assertSame(['en'], Carbon::getAvailableLocales());
     }
 
-    public function testNotLocaleAwareException()
-    {
-        if (method_exists(TranslatorInterface::class, 'getLocale')) {
-            $this->markTestSkipped('In Symfony < 5, NotLocaleAwareException will never been thrown.');
-        }
-
-        $translator = new class() implements TranslatorInterface {
-            public function trans(string $id, array $parameters = [], ?string $domain = null, ?string $locale = null)
-            {
-                return 'x';
-            }
-        };
-
-        Carbon::setTranslator($translator);
-
-        $this->expectExceptionObject(new NotLocaleAwareException(
-            $translator
-        ));
-
-        Carbon::now()->locale();
-    }
-
     public function testGetAvailableLocalesInfo()
     {
         $infos = Carbon::getAvailableLocalesInfo();
@@ -760,21 +763,31 @@ class LocalizationTest extends AbstractTestCase
     public function testTranslationCustomWithCustomTranslator()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Translator does not implement Symfony\Component\Translation\TranslatorInterface '.
+            'Translator does not implement Symfony\Contracts\Translation\TranslatorInterface '.
             'and Symfony\Component\Translation\TranslatorBagInterface. '.
-            'Symfony\Component\Translation\IdentityTranslator has been given.'
+            'Symfony\Component\Translation\IdentityTranslator has been given.',
         ));
 
         $date = Carbon::create(2018, 1, 1, 0, 0, 0);
-        $date->setLocalTranslator(
-            class_exists(MessageSelector::class)
-                ? new IdentityTranslator(new MessageSelector())
-                : new IdentityTranslator()
-        );
+        $date->setLocalTranslator(new IdentityTranslator());
 
         $date->getTranslationMessage('foo');
     }
 
+    public function testNoLocaleTranslator()
+    {
+        $this->expectException(InvalidArgumentException::class);
+        $this->expectExceptionMessage(
+            'Tests\Carbon\Fixtures\NoLocaleTranslator does neither implements '.
+            'Symfony\Contracts\Translation\LocaleAwareInterface nor getLocale() method.',
+        );
+
+        $date = Carbon::create(2018, 1, 1, 0, 0, 0);
+        $date->setLocalTranslator(new NoLocaleTranslator());
+
+        $date->locale;
+    }
+
     public function testTranslateTimeStringTo()
     {
         $date = Carbon::parse('2019-07-05')->locale('de');
@@ -876,7 +889,7 @@ class LocalizationTest extends AbstractTestCase
     {
         $this->assertSame(
             '29 февраля 2020 г., 12:24',
-            Carbon::parse('2020-02-29 12:24:00')->locale('ru_RU')->isoFormat('LLL')
+            Carbon::parse('2020-02-29 12:24:00')->locale('ru_RU')->isoFormat('LLL'),
         );
     }
 
@@ -884,12 +897,12 @@ class LocalizationTest extends AbstractTestCase
     {
         $this->assertSame(
             'година',
-            CarbonInterval::hour()->locale('uk')->forHumans(['aUnit' => true])
+            CarbonInterval::hour()->locale('uk')->forHumans(['aUnit' => true]),
         );
 
         $this->assertSame(
             'годину тому',
-            Carbon::now()->subHour()->locale('uk')->diffForHumans(['aUnit' => true])
+            Carbon::now()->subHour()->locale('uk')->diffForHumans(['aUnit' => true]),
         );
     }
 
@@ -897,22 +910,22 @@ class LocalizationTest extends AbstractTestCase
     {
         $this->assertSame(
             'Jänner',
-            Carbon::parse('2020-01-15')->locale('de_AT')->monthName
+            Carbon::parse('2020-01-15')->locale('de_AT')->monthName,
         );
 
         $this->assertSame(
             'Januar',
-            Carbon::parse('2020-01-15')->locale('de')->monthName
+            Carbon::parse('2020-01-15')->locale('de')->monthName,
         );
 
         $this->assertSame(
             'Februar',
-            Carbon::parse('2020-02-15')->locale('de_AT')->monthName
+            Carbon::parse('2020-02-15')->locale('de_AT')->monthName,
         );
 
         $this->assertSame(
             'Februar',
-            Carbon::parse('2020-02-15')->locale('de')->monthName
+            Carbon::parse('2020-02-15')->locale('de')->monthName,
         );
     }
 
@@ -940,4 +953,20 @@ class LocalizationTest extends AbstractTestCase
                 ->diffForHumans(null, null, false, 4)
         );
     }
+
+    /** @see https://github.com/CarbonPHP/carbon/issues/57 */
+    public function testResetMessagesMemoryConsumption()
+    {
+        Carbon::getTranslator()->resetMessages('en');
+
+        $start = memory_get_usage();
+
+        for ($i = 0; $i < 100; $i++) {
+            Carbon::getTranslator()->resetMessages('en');
+        }
+
+        $consumedMemory = memory_get_usage() - $start;
+
+        $this->assertLessThan(100_000, $consumedMemory);
+    }
 }
