@@ -34,7 +34,7 @@ class SetDateAndTimeFromTest extends AbstractTestCase
             $source->day,
             $target->hour,
             $target->minute,
-            $target->second
+            $target->second,
         );
     }
 
@@ -54,7 +54,27 @@ class SetDateAndTimeFromTest extends AbstractTestCase
             $target->day,
             $source->hour,
             $source->minute,
-            $source->second
+            $source->second,
+        );
+    }
+
+    public function testSetDateTimeFrom()
+    {
+        $source = Carbon::now();
+        $target = $source->copy()
+            ->addDays(rand(1, 6))
+            ->addHours(rand(1, 23))
+            ->addMinutes(rand(1, 59))
+            ->addSeconds(rand(1, 59));
+
+        $this->assertCarbon(
+            $target->copy()->setDateTimeFrom($source),
+            $source->year,
+            $source->month,
+            $source->day,
+            $source->hour,
+            $source->minute,
+            $source->second,
         );
     }
 }
