@@ -13,18 +13,57 @@ declare(strict_types=1);
 
 namespace Tests\Carbon;
 
+use BadMethodCallException;
 use Carbon\Carbon;
+use Carbon\Exceptions\InvalidFormatException;
+use Carbon\Exceptions\InvalidIntervalException;
 use Carbon\Exceptions\UnitException;
+use Carbon\Exceptions\UnsupportedUnitException;
+use Carbon\Month;
+use Carbon\Unit;
+use DateInterval;
 use DateTimeZone;
 use Exception;
-use Generator;
 use InvalidArgumentException;
+use PHPUnit\Framework\Attributes\TestWith;
 use Tests\AbstractTestCase;
 
 class SettersTest extends AbstractTestCase
 {
     public const SET_UNIT_NO_OVERFLOW_SAMPLE = 200;
 
+    public function testMonthEnum()
+    {
+        $d = Carbon::parse('2023-10-25 21:14:51');
+        $d->month = Month::February;
+
+        $this->assertSame('2023-02-25 21:14:51', $d->format('Y-m-d H:i:s'));
+
+        $d->setMonth(Month::July);
+
+        $this->assertSame('2023-07-25 21:14:51', $d->format('Y-m-d H:i:s'));
+    }
+
+    public function testSetMonthUnit()
+    {
+        $d = Carbon::parse('2023-10-25 21:14:51');
+        $d->set(Unit::Month, Month::February);
+
+        $this->assertSame(2, $d->get(Unit::Month));
+        $this->assertSame('2023-02-25 21:14:51', $d->format('Y-m-d H:i:s'));
+    }
+
+    public function testMonthEnumOnWrongUnit()
+    {
+        $this->expectExceptionObject(new UnitException(
+            'Month enum cannot be used to set year',
+        ));
+
+        $d = Carbon::now();
+        // @phpstan-ignore-next-line
+        $d->year = Month::February;
+    }
+
     public function testSingularUnit()
     {
         $this->assertSame('year', Carbon::singularUnit('year'));
@@ -127,6 +166,66 @@ class SettersTest extends AbstractTestCase
         $this->assertSame(2, $d->second);
     }
 
+    public function testUnitOfUnit()
+    {
+        $date = Carbon::create(2023, 1, 27, 20, 12, 42, 'America/Toronto');
+        $date->minuteOfYear = (95 * 24 + 3) * 60 + 50;
+
+        $this->assertSame('2023-04-06 04:50:42 America/Toronto', $date->format('Y-m-d H:i:s e'));
+
+        $date->dayOfWeek = 2;
+
+        $this->assertSame('2023-04-04 04:50:42 America/Toronto', $date->format('Y-m-d H:i:s e'));
+
+        $date->dayOfWeek = 6;
+
+        $this->assertSame('2023-04-08 04:50:42 America/Toronto', $date->format('Y-m-d H:i:s e'));
+
+        $date->dayOfWeek = 0;
+
+        $this->assertSame('2023-04-02 04:50:42 America/Toronto', $date->format('Y-m-d H:i:s e'));
+
+        $date->dayOfWeekIso = 7;
+
+        $this->assertSame('2023-04-02 04:50:42 America/Toronto', $date->format('Y-m-d H:i:s e'));
+
+        $date->dayOfWeek = 4;
+
+        $this->assertSame('2023-04-06 04:50:42 America/Toronto', $date->format('Y-m-d H:i:s e'));
+
+        $date->dayOfWeekIso = 7;
+
+        $this->assertSame('2023-04-09 04:50:42 America/Toronto', $date->format('Y-m-d H:i:s e'));
+    }
+
+    public function testUnitOfUnitMethod()
+    {
+        $date = Carbon::create(2023, 1, 27, 20, 12, 42, 'America/Toronto');
+        $date->minuteOfYear((95 * 24 + 3) * 60 + 50);
+
+        $this->assertSame('2023-04-06 04:50:42 America/Toronto', $date->format('Y-m-d H:i:s e'));
+    }
+
+    public function testUnitOfUnitUnknownMethod()
+    {
+        $this->expectExceptionObject(new BadMethodCallException(
+            'Method fooOfBar does not exist.',
+        ));
+
+        $date = Carbon::create(2023, 1, 27, 20, 12, 42, 'America/Toronto');
+        $date->fooOfBar((95 * 24 + 3) * 60 + 50);
+    }
+
+    public function testUnitOfUnitFloat()
+    {
+        $this->expectExceptionObject(new UnitException(
+            '->minuteOfYear expects integer value',
+        ));
+
+        $date = Carbon::create(2018, 1, 27, 20, 12, 42, 'America/Toronto');
+        $date->minuteOfYear = (float) ((95 * 24 + 3) * 60 + 50);
+    }
+
     public function testTimeSetter()
     {
         $d = Carbon::now();
@@ -241,8 +340,13 @@ class SettersTest extends AbstractTestCase
         $d->timestamp = 1600887164.88952298;
         $this->assertSame('2020-09-23 14:52:44.889523', $d->format('Y-m-d H:i:s.u'));
 
-        $d->setTimestamp(1599828571.23561248);
-        $this->assertSame(PHP_VERSION_ID < 80400 ? '2020-09-11 08:49:31.235612' : '2020-09-11 08:49:31.235613', $d->format('Y-m-d H:i:s.u'));
+        $d->setTimestamp(
+            // See https://github.com/php/php-src/issues/14332
+            PHP_VERSION < 8.4
+                ? 1599828571.23561248
+                : 1599828571.2356121,
+        );
+        $this->assertSame('2020-09-11 08:49:31.235612', $d->format('Y-m-d H:i:s.u'));
 
         $d->timestamp = '0.88951247 1600887164';
         $this->assertSame('2020-09-23 14:52:44.889512', $d->format('Y-m-d H:i:s.u'));
@@ -260,7 +364,7 @@ class SettersTest extends AbstractTestCase
     public function testSetTimezoneWithInvalidTimezone()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Unknown or bad timezone (sdf)'
+            'Unknown or bad timezone (sdf)',
         ));
 
         $d = Carbon::now();
@@ -270,7 +374,7 @@ class SettersTest extends AbstractTestCase
     public function testTimezoneWithInvalidTimezone()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Unknown or bad timezone (sdf)'
+            'Unknown or bad timezone (sdf)',
         ));
 
         /** @var mixed $d */
@@ -351,7 +455,7 @@ class SettersTest extends AbstractTestCase
     public function testTimezoneWithInvalidTimezoneSetter()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Unknown or bad timezone (sdf)'
+            'Unknown or bad timezone (sdf)',
         ));
 
         $d = Carbon::now();
@@ -361,7 +465,7 @@ class SettersTest extends AbstractTestCase
     public function testTzWithInvalidTimezone()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Unknown or bad timezone (sdf)'
+            'Unknown or bad timezone (sdf)',
         ));
 
         /** @var mixed $d */
@@ -372,7 +476,7 @@ class SettersTest extends AbstractTestCase
     public function testTzWithInvalidTimezoneSetter()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Unknown or bad timezone (sdf)'
+            'Unknown or bad timezone (sdf)',
         ));
 
         $d = Carbon::now();
@@ -490,7 +594,7 @@ class SettersTest extends AbstractTestCase
     public function testInvalidSetter()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            "Unknown setter 'doesNotExit'"
+            "Unknown setter 'doesNotExit'",
         ));
 
         /** @var mixed $date */
@@ -498,31 +602,19 @@ class SettersTest extends AbstractTestCase
         $date->doesNotExit = 'bb';
     }
 
-    /**
-     * @dataProvider \Tests\Carbon\SettersTest::dataForTestSetTimeFromTimeString
-     *
-     * @param int    $hour
-     * @param int    $minute
-     * @param int    $second
-     * @param string $time
-     */
-    public function testSetTimeFromTimeString($hour, $minute, $second, $time)
+    #[TestWith([9, 15, 30, '09:15:30'])]
+    #[TestWith([9, 15, 0, '09:15'])]
+    #[TestWith([9, 0, 0, '09'])]
+    #[TestWith([9, 5, 3, '9:5:3'])]
+    #[TestWith([9, 5, 0, '9:5'])]
+    #[TestWith([9, 0, 0, '9'])]
+    public function testSetTimeFromTimeString(int $hour, int $minute, int $second, string $time)
     {
         Carbon::setTestNow(Carbon::create(2016, 2, 12, 1, 2, 3));
         $d = Carbon::now()->setTimeFromTimeString($time);
         $this->assertCarbon($d, 2016, 2, 12, $hour, $minute, $second);
     }
 
-    public static function dataForTestSetTimeFromTimeString(): Generator
-    {
-        yield [9, 15, 30, '09:15:30'];
-        yield [9, 15, 0, '09:15'];
-        yield [9, 0, 0, '09'];
-        yield [9, 5, 3, '9:5:3'];
-        yield [9, 5, 0, '9:5'];
-        yield [9, 0, 0, '9'];
-    }
-
     public function testWeekendDaysSetter()
     {
         $weekendDays = [Carbon::FRIDAY,Carbon::SATURDAY];
@@ -541,13 +633,21 @@ class SettersTest extends AbstractTestCase
         $this->assertSame(12, $d->getMidDayAt());
     }
 
+    public function testSetUnitNoOverflowFebruary()
+    {
+        $d = Carbon::parse('2024-02-29')->setUnitNoOverFlow('day', 31, 'month');
+
+        $this->assertInstanceOf(Carbon::class, $d);
+        $this->assertSame('2024-02-29 23:59:59.999999', $d->format('Y-m-d H:i:s.u'));
+    }
+
     public function testSetUnitNoOverflow()
     {
         $results = [
             'current' => 0,
             'start' => 0,
             'end' => 0,
-            'failure' => 0,
+            'failure' => [],
         ];
 
         for ($i = 0; $i < static::SET_UNIT_NO_OVERFLOW_SAMPLE; $i++) {
@@ -570,31 +670,50 @@ class SettersTest extends AbstractTestCase
                 'microsecond' => 1000000,
             ];
             $valueUnit = array_keys($units)[mt_rand(0, \count($units) - 1)];
-            $value = mt_rand() > 0.5 ?
+            $value = mt_rand(0, 1) === 1 ?
                 mt_rand(-9999, 9999) :
                 mt_rand(-60, 60);
 
-            $date = Carbon::create($year, $month, $day, $hour, $minute, $second + $microsecond / 1000000);
+            $date = Carbon::create($year, $month, $day, $hour, $minute, $second + $microsecond / 1000000, 'UTC');
             $original = $date->copy();
             $date->setUnitNoOverflow($valueUnit, $value, $overflowUnit);
             $start = $original->copy()->startOf($overflowUnit);
             $end = $original->copy()->endOf($overflowUnit);
 
-            if ($date < $start || $date > $end) {
-                $results['failure']++;
+            if ($date->lessThan($start) || $date->greaterThan($end)) {
+                $results['failure'][] = [
+                    'year' => $year,
+                    'month' => $month,
+                    'day' => $day,
+                    'hour' => $hour,
+                    'minute' => $minute,
+                    'second' => $second,
+                    'microsecond' => $microsecond,
+                    'valueUnit' => $valueUnit,
+                    'value' => $value,
+                    'overflowUnit' => $overflowUnit,
+                    'date' => $date->format('Y-m-d H:i:s'),
+                    'start' => $start->format('Y-m-d H:i:s'),
+                    'end' => $end->format('Y-m-d H:i:s'),
+                ];
 
                 continue;
             }
 
             $unit = ucfirst(Carbon::pluralUnit($valueUnit));
             $modulo = $value % $units[$valueUnit];
+
             if ($modulo < 0) {
                 $modulo += $units[$valueUnit];
             }
+
             if ($value === $date->$valueUnit ||
                 $modulo === $date->$valueUnit ||
-                (method_exists($date, "diffInReal$unit") && $$valueUnit - $date->{"diffInReal$unit"}($original, false) === $value) ||
-                $$valueUnit - $date->{"diffIn$unit"}($original, false) === $value
+                $$valueUnit - ((int) $date->{"diffIn$unit"}($original, false)) === $value ||
+                ($valueUnit === 'day' &&
+                    $date->format('Y-m-d H:i:s.u') === $original->copy()
+                        ->modify(($original->day + $value).' days')
+                        ->format('Y-m-d H:i:s.u'))
             ) {
                 $results['current']++;
 
@@ -624,12 +743,12 @@ class SettersTest extends AbstractTestCase
                 $overflowUnit,
                 $unit,
                 $modulo,
-                $$valueUnit
+                $$valueUnit,
             );
         }
 
         $minimum = static::SET_UNIT_NO_OVERFLOW_SAMPLE / 100;
-        $this->assertSame(0, $results['failure']);
+        $this->assertSame([], $results['failure']);
         $this->assertGreaterThan($minimum, $results['start']);
         $this->assertGreaterThan($minimum, $results['end']);
         $this->assertGreaterThan($minimum, $results['current']);
@@ -639,7 +758,7 @@ class SettersTest extends AbstractTestCase
     public function testSetUnitNoOverflowInputUnitException()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Unknown unit \'anyUnit\''
+            'Unknown unit \'anyUnit\'',
         ));
 
         Carbon::now()->setUnitNoOverflow('anyUnit', 1, 'year');
@@ -648,7 +767,7 @@ class SettersTest extends AbstractTestCase
     public function testSetUnitNoOverflowOverflowUnitException()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Unknown unit \'anyUnit\''
+            'Unknown unit \'anyUnit\'',
         ));
 
         Carbon::now()->setUnitNoOverflow('minute', 1, 'anyUnit');
@@ -667,13 +786,52 @@ class SettersTest extends AbstractTestCase
         @$date->addUnit('foobar', 1);
     }
 
+    public function testUnsupportedUnitException()
+    {
+        $date = new class('2021-09-13') extends Carbon {
+            public function rawAdd(DateInterval $interval): static
+            {
+                throw new InvalidIntervalException('InvalidIntervalException');
+            }
+
+            public function modify($modifier): static
+            {
+                throw new InvalidFormatException('InvalidFormatException');
+            }
+        };
+
+        $exception = null;
+
+        try {
+            $date->addUnit('year', 999);
+        } catch (UnitException $error) {
+            $exception = $error;
+        }
+
+        $this->assertSame(
+            'Unable to add unit '.var_export(['year', 999], true),
+            $exception?->getMessage(),
+        );
+
+        $previous = $exception->getPrevious();
+
+        $this->assertInstanceOf(UnsupportedUnitException::class, $previous);
+        $this->assertSame("Unsupported unit 'year'", $previous->getMessage());
+
+        $previous = $previous->getPrevious();
+
+        $this->assertInstanceOf(InvalidIntervalException::class, $previous);
+        $this->assertSame('InvalidIntervalException', $previous->getMessage());
+        $this->assertNull($previous->getPrevious());
+    }
+
     public function testAddUnitNoOverflow()
     {
         $results = [
             'current' => 0,
             'start' => 0,
             'end' => 0,
-            'failure' => 0,
+            'failure' => [],
         ];
 
         for ($i = 0; $i < static::SET_UNIT_NO_OVERFLOW_SAMPLE; $i++) {
@@ -696,7 +854,7 @@ class SettersTest extends AbstractTestCase
                 'microsecond' => 1000000,
             ];
             $valueUnit = array_keys($units)[mt_rand(0, \count($units) - 1)];
-            $value = mt_rand() > 0.5 ?
+            $value = mt_rand(0, 1) === 1 ?
                 mt_rand(-9999, 9999) :
                 mt_rand(-60, 60);
 
@@ -706,8 +864,22 @@ class SettersTest extends AbstractTestCase
             $start = $original->copy()->startOf($overflowUnit);
             $end = $original->copy()->endOf($overflowUnit);
 
-            if ($date < $start || $date > $end) {
-                $results['failure']++;
+            if ($date->lessThan($start) || $date->greaterThan($end)) {
+                $results['failure'][] = [
+                    'year' => $year,
+                    'month' => $month,
+                    'day' => $day,
+                    'hour' => $hour,
+                    'minute' => $minute,
+                    'second' => $second,
+                    'microsecond' => $microsecond,
+                    'valueUnit' => $valueUnit,
+                    'value' => $value,
+                    'overflowUnit' => $overflowUnit,
+                    'date' => $date->format('Y-m-d H:i:s.u e O'),
+                    'start' => $start->format('Y-m-d H:i:s.u e O'),
+                    'end' => $end->format('Y-m-d H:i:s.u e O'),
+                ];
 
                 continue;
             }
@@ -719,8 +891,7 @@ class SettersTest extends AbstractTestCase
             }
             if ($value === $date->$valueUnit ||
                 $modulo === $date->$valueUnit ||
-                (method_exists($date, "diffInReal$unit") && -$date->{"diffInReal$unit"}($original, false) === $value) ||
-                -$date->{"diffIn$unit"}($original, false) === $value
+                (method_exists($date, "diffInReal$unit") && -$date->{"diffInReal$unit"}($original, false) === $value)
             ) {
                 $results['current']++;
 
@@ -739,6 +910,33 @@ class SettersTest extends AbstractTestCase
                 continue;
             }
 
+            $currentDiff = -((int) round($date->{"diffIn$unit"}($original, false)));
+
+            if ($currentDiff === $value) {
+                $results['current']++;
+
+                continue;
+            }
+
+            $delta = ($currentDiff - $value);
+
+            if ($valueUnit === 'hour') {
+                $diff = $this->getOffsetChangeOfTheDay($date) ?: $this->getOffsetChangeOfTheDay($original);
+
+                if ($diff !== 0) {
+                    $sign = $diff < 0 ? -1 : 1;
+                    $diff = abs($diff);
+                    $minutes = $diff % 100;
+                    $hours = (int) ($sign * (floor($diff / 100) + $minutes / 60));
+
+                    if ($delta === -$hours) {
+                        $results['current']++;
+
+                        continue;
+                    }
+                }
+            }
+
             $this->failOperation(
                 $original,
                 $date,
@@ -750,12 +948,12 @@ class SettersTest extends AbstractTestCase
                 $overflowUnit,
                 $unit,
                 $modulo,
-                $$valueUnit
+                $value,
             );
         }
 
         $minimum = static::SET_UNIT_NO_OVERFLOW_SAMPLE / 100;
-        $this->assertSame(0, $results['failure']);
+        $this->assertSame([], $results['failure']);
         $this->assertGreaterThan($minimum, $results['start']);
         $this->assertGreaterThan($minimum, $results['end']);
         $this->assertGreaterThan($minimum, $results['current']);
@@ -768,7 +966,7 @@ class SettersTest extends AbstractTestCase
             'current' => 0,
             'start' => 0,
             'end' => 0,
-            'failure' => 0,
+            'failure' => [],
         ];
 
         for ($i = 0; $i < static::SET_UNIT_NO_OVERFLOW_SAMPLE; $i++) {
@@ -791,7 +989,7 @@ class SettersTest extends AbstractTestCase
                 'microsecond' => 1000000,
             ];
             $valueUnit = array_keys($units)[mt_rand(0, \count($units) - 1)];
-            $value = mt_rand() > 0.5 ?
+            $value = mt_rand(0, 1) === 1 ?
                 mt_rand(-9999, 9999) :
                 mt_rand(-60, 60);
 
@@ -801,8 +999,22 @@ class SettersTest extends AbstractTestCase
             $start = $original->copy()->startOf($overflowUnit);
             $end = $original->copy()->endOf($overflowUnit);
 
-            if ($date < $start || $date > $end) {
-                $results['failure']++;
+            if ($date->lessThan($start) || $date->greaterThan($end)) {
+                $results['failure'][] = [
+                    'year' => $year,
+                    'month' => $month,
+                    'day' => $day,
+                    'hour' => $hour,
+                    'minute' => $minute,
+                    'second' => $second,
+                    'microsecond' => $microsecond,
+                    'valueUnit' => $valueUnit,
+                    'value' => $value,
+                    'overflowUnit' => $overflowUnit,
+                    'date' => $date->format('Y-m-d H:i:s.u e O'),
+                    'start' => $start->format('Y-m-d H:i:s.u e O'),
+                    'end' => $end->format('Y-m-d H:i:s.u e O'),
+                ];
 
                 continue;
             }
@@ -816,14 +1028,28 @@ class SettersTest extends AbstractTestCase
 
             if ($value === $date->$valueUnit ||
                 $modulo === $date->$valueUnit ||
-                (method_exists($date, "diffInReal$unit") && $value === $date->{"diffInReal$unit"}($original, false)) ||
-                $value === $date->{"diffIn$unit"}($original, false)
+                (method_exists($date, "diffInReal$unit") && $value === $date->{"diffInReal$unit"}($original, false))
             ) {
                 $results['current']++;
 
                 continue;
             }
 
+            if ($valueUnit === 'day') {
+                $dateInterval = $date->diffAsDateInterval($original);
+                $days = $dateInterval->days;
+
+                if ($days !== false) {
+                    $days *= $dateInterval->invert ? -1 : 1;
+
+                    if ($value === $days) {
+                        $results['current']++;
+
+                        continue;
+                    }
+                }
+            }
+
             if ($date->$valueUnit === $start->$valueUnit) {
                 $results['start']++;
 
@@ -836,6 +1062,33 @@ class SettersTest extends AbstractTestCase
                 continue;
             }
 
+            $currentDiff = (int) round($date->{"diffIn$unit"}($original, false));
+
+            if ($currentDiff === $value) {
+                $results['current']++;
+
+                continue;
+            }
+
+            $delta = ($currentDiff - $value);
+
+            if ($valueUnit === 'hour') {
+                $diff = $this->getOffsetChangeOfTheDay($date) ?: $this->getOffsetChangeOfTheDay($original);
+
+                if ($diff !== 0) {
+                    $sign = $diff < 0 ? -1 : 1;
+                    $diff = abs($diff);
+                    $minutes = $diff % 100;
+                    $hours = (int) ($sign * (floor($diff / 100) + $minutes / 60));
+
+                    if ($delta === $hours) {
+                        $results['current']++;
+
+                        continue;
+                    }
+                }
+            }
+
             $this->failOperation(
                 $original,
                 $date,
@@ -847,20 +1100,52 @@ class SettersTest extends AbstractTestCase
                 $overflowUnit,
                 $unit,
                 $modulo,
-                $$valueUnit
+                $value,
+                $hours ?? null,
+                $delta,
             );
         }
 
         $minimum = static::SET_UNIT_NO_OVERFLOW_SAMPLE / 100;
-        $this->assertSame(0, $results['failure']);
+        $this->assertSame([], $results['failure']);
         $this->assertGreaterThan($minimum, $results['start']);
         $this->assertGreaterThan($minimum, $results['end']);
         $this->assertGreaterThan($minimum, $results['current']);
         $this->assertSame(static::SET_UNIT_NO_OVERFLOW_SAMPLE, $results['end'] + $results['start'] + $results['current']);
     }
 
+    public function testOverflowInDst()
+    {
+        $date = Carbon::create(2335, 11, 3, 1, 30, 50.138159)
+            ->subUnitNoOverflow('year', 5668, 'second');
+
+        $this->assertSame(
+            '2335-11-03 01:30:50.000000 America/Toronto -0400',
+            $date->format('Y-m-d H:i:s.u e O'),
+        );
+
+        $date = Carbon::parse('2020-10-15 03:22:57.442989', 'America/Toronto')->hours(-5302);
+
+        $diff = (int) ($date->copy()->startOfDay()->format('O') - $date->copy()->endOfDay()->format('O'));
+        $sign = $diff < 0 ? -1 : 1;
+        $diff = abs($diff);
+        $minutes = $diff % 100;
+        $hours = $sign * (floor($diff / 100) + $minutes / 60);
+
+        $diffInHours = $date->diffInHours(
+            Carbon::parse('2020-10-15 03:22:57.442989', 'America/Toronto'),
+        );
+
+        $this->assertSame(5305.0 + $hours, $diffInHours);
+    }
+
+    private function getOffsetChangeOfTheDay(Carbon $date): int
+    {
+        return (int) ($date->copy()->startOfDay()->format('O') - $date->copy()->endOfDay()->format('O'));
+    }
+
     /**
-     * @SuppressWarnings(PHPMD.TooManyFields)
+     * @SuppressWarnings(TooManyFields)
      */
     private function failOperation(
         Carbon $original,
@@ -873,7 +1158,9 @@ class SettersTest extends AbstractTestCase
         string $overflowUnit,
         string $unit,
         int $modulo,
-        int $variableValue
+        int $variableValue,
+        ?int $hours = null,
+        ?int $delta = null,
     ): void {
         throw new Exception(implode("\n", [
             'Unhandled result for: '.
@@ -882,12 +1169,15 @@ class SettersTest extends AbstractTestCase
             ")->$method(".implode(', ', array_map(function ($value) {
                 return var_export($value, true);
             }, [$valueUnit, $value, $overflowUnit])).');',
-            'Getting: '.$date->format('Y-m-d H:i:s.u e'),
+            'Getting: '.$date->format('Y-m-d H:i:s.u e O'),
             "Current $valueUnit: ".$date->$valueUnit,
             'Is neither '.$start->$valueUnit." (from $start)",
             'Nor '.$end->$valueUnit." (from $end)",
             "Nor $value (from value)",
             "Nor $modulo (from modulo)",
+            ...($hours !== null ? [
+                "Not matching diff (hours = $hours vs delta = ".($delta ?? 'null').')',
+            ] : []),
             method_exists($date, "diffInReal$unit")
                 ? "diffInReal$unit() exists and returns ".$date->{"diffInReal$unit"}($original, false)
                     ." while expecting $variableValue"
