@@ -31,7 +31,7 @@ class AddTest extends AbstractTestCase
                 $lastNegated = $negated;
 
                 return new DateTimeImmutable($date->format('Y-m-d H:i:s').' + 2 years');
-            }
+            },
         );
         $this->assertInstanceOf(Carbon::class, $date);
         $this->assertSame(1977, $date->year);
@@ -95,15 +95,15 @@ class AddTest extends AbstractTestCase
     {
         $this->assertSame(
             '2021-03-03',
-            Carbon::parse('2021-01-31')->add(1, 'months', true)->format('Y-m-d')
+            Carbon::parse('2021-01-31')->add(1, 'months', true)->format('Y-m-d'),
         );
         $this->assertSame(
             '2021-03-03',
-            Carbon::parse('2021-01-31')->add(1, 'months')->format('Y-m-d')
+            Carbon::parse('2021-01-31')->add(1, 'months')->format('Y-m-d'),
         );
         $this->assertSame(
             '2021-02-28',
-            Carbon::parse('2021-01-31')->add(1, 'months', false)->format('Y-m-d')
+            Carbon::parse('2021-01-31')->add(1, 'months', false)->format('Y-m-d'),
         );
     }
 
@@ -214,6 +214,26 @@ class AddTest extends AbstractTestCase
         $this->assertSame(59, Carbon::createFromTime(0, 0, 0)->addSeconds(-1)->second);
     }
 
+    public function testAddDecimalSeconds()
+    {
+        $this->assertSame(
+            '1999-12-31 23:59:58.500000',
+            Carbon::parse('2000-01-01 00:00:00')->addSeconds(-1.5)->format('Y-m-d H:i:s.u'),
+        );
+        $this->assertSame(
+            '2000-01-01 00:00:01.500000',
+            Carbon::parse('2000-01-01 00:00:00')->addSeconds(1.5)->format('Y-m-d H:i:s.u'),
+        );
+        $this->assertSame(
+            '1999-12-31 23:59:58.500000',
+            Carbon::parse('2000-01-01 00:00:00')->addRealSeconds(-1.5)->format('Y-m-d H:i:s.u'),
+        );
+        $this->assertSame(
+            '2000-01-01 00:00:01.500000',
+            Carbon::parse('2000-01-01 00:00:00')->addRealSeconds(1.5)->format('Y-m-d H:i:s.u'),
+        );
+    }
+
     public function testAddSecond()
     {
         $this->assertSame(1, Carbon::createFromTime(0, 0, 0)->addSecond()->second);
