@@ -14,6 +14,7 @@ declare(strict_types=1);
 namespace Tests\CarbonImmutable;
 
 use Carbon\CarbonImmutable as Carbon;
+use PHPUnit\Framework\Attributes\TestWith;
 use Tests\AbstractTestCase;
 
 class StartEndOfTest extends AbstractTestCase
@@ -358,31 +359,19 @@ class StartEndOfTest extends AbstractTestCase
         $this->assertInstanceOfCarbon($dt->startOfQuarter());
     }
 
-    public static function dataForTestStartOfQuarter()
-    {
-        return [
-            [1, 1],
-            [2, 1],
-            [3, 1],
-            [4, 4],
-            [5, 4],
-            [6, 4],
-            [7, 7],
-            [8, 7],
-            [9, 7],
-            [10, 10],
-            [11, 10],
-            [12, 10],
-        ];
-    }
-
-    /**
-     * @dataProvider \Tests\CarbonImmutable\StartEndOfTest::dataForTestStartOfQuarter
-     *
-     * @param int $month
-     * @param int $startOfQuarterMonth
-     */
-    public function testStartOfQuarter($month, $startOfQuarterMonth)
+    #[TestWith([1, 1])]
+    #[TestWith([2, 1])]
+    #[TestWith([3, 1])]
+    #[TestWith([4, 4])]
+    #[TestWith([5, 4])]
+    #[TestWith([6, 4])]
+    #[TestWith([7, 7])]
+    #[TestWith([8, 7])]
+    #[TestWith([9, 7])]
+    #[TestWith([10, 10])]
+    #[TestWith([11, 10])]
+    #[TestWith([12, 10])]
+    public function testStartOfQuarter(int $month, int $startOfQuarterMonth)
     {
         $dt = Carbon::create(2015, $month, 15, 1, 2, 3);
         $this->assertCarbon($dt->startOfQuarter(), 2015, $startOfQuarterMonth, 1, 0, 0, 0);
@@ -394,32 +383,19 @@ class StartEndOfTest extends AbstractTestCase
         $this->assertInstanceOfCarbon($dt->endOfQuarter());
     }
 
-    public static function dataForTestEndOfQuarter()
-    {
-        return [
-            [1, 3, 31],
-            [2, 3, 31],
-            [3, 3, 31],
-            [4, 6, 30],
-            [5, 6, 30],
-            [6, 6, 30],
-            [7, 9, 30],
-            [8, 9, 30],
-            [9, 9, 30],
-            [10, 12, 31],
-            [11, 12, 31],
-            [12, 12, 31],
-        ];
-    }
-
-    /**
-     * @dataProvider \Tests\CarbonImmutable\StartEndOfTest::dataForTestEndOfQuarter
-     *
-     * @param int $month
-     * @param int $endOfQuarterMonth
-     * @param int $endOfQuarterDay
-     */
-    public function testEndOfQuarter($month, $endOfQuarterMonth, $endOfQuarterDay)
+    #[TestWith([1, 3, 31])]
+    #[TestWith([2, 3, 31])]
+    #[TestWith([3, 3, 31])]
+    #[TestWith([4, 6, 30])]
+    #[TestWith([5, 6, 30])]
+    #[TestWith([6, 6, 30])]
+    #[TestWith([7, 9, 30])]
+    #[TestWith([8, 9, 30])]
+    #[TestWith([9, 9, 30])]
+    #[TestWith([10, 12, 31])]
+    #[TestWith([11, 12, 31])]
+    #[TestWith([12, 12, 31])]
+    public function testEndOfQuarter(int $month, int $endOfQuarterMonth, int $endOfQuarterDay)
     {
         $dt = Carbon::create(2015, $month, 15, 1, 2, 3);
         $this->assertCarbon($dt->endOfQuarter(), 2015, $endOfQuarterMonth, $endOfQuarterDay, 23, 59, 59);
