@@ -23,7 +23,7 @@ class CreateFromFormatTest extends AbstractTestCase
     {
         $this->expectExceptionObject(new ParseErrorException(
             'number',
-            ''
+            '',
         ));
 
         CarbonInterval::createFromFormat('H:i:s', '');
@@ -33,7 +33,7 @@ class CreateFromFormatTest extends AbstractTestCase
     {
         $this->expectExceptionObject(new ParseErrorException(
             'number',
-            ''
+            '',
         ));
 
         CarbonInterval::createFromFormat('H:i:s', null);
@@ -43,7 +43,7 @@ class CreateFromFormatTest extends AbstractTestCase
     {
         $this->expectExceptionObject(new ParseErrorException(
             'end of string',
-            ':25'
+            ':25',
         ));
 
         CarbonInterval::createFromFormat('H:i', '01:30:25');
@@ -57,8 +57,8 @@ class CreateFromFormatTest extends AbstractTestCase
                 '4',
                 'Allowed substitutes for interval formats are y, Y, o, m, n, W, d, j, z, h, g, H, G, i, s, u, v'.
                 "\n".
-                'See https://php.net/manual/en/function.date.php for their meaning'
-            )
+                'See https://php.net/manual/en/function.date.php for their meaning',
+            ),
         );
 
         CarbonInterval::createFromFormat('N', '4');
@@ -185,6 +185,13 @@ class CreateFromFormatTest extends AbstractTestCase
         $this->assertCarbonInterval($ci, 0, 0, 0, 0, 0, 0, 200000);
     }
 
+    public function testTime()
+    {
+        $ci = CarbonInterval::createFromFormat('H:i:s', '00:05:00');
+        $this->assertInstanceOfCarbonInterval($ci);
+        $this->assertCarbonInterval($ci, 0, 0, 0, 0, 5, 0, 0);
+    }
+
     public function testAll()
     {
         $ci = CarbonInterval::createFromFormat('Y-m-d H:i:s.u', '2000-01-02 3:04:05.500000');
