@@ -13,8 +13,10 @@ declare(strict_types=1);
 
 namespace Tests\CarbonInterval;
 
+use Carbon\Carbon;
 use Carbon\CarbonInterval;
 use Carbon\Translator;
+use DateTimeZone;
 use InvalidArgumentException;
 use Tests\AbstractTestCase;
 
@@ -23,7 +25,7 @@ class GettersTest extends AbstractTestCase
     public function testGettersThrowExceptionOnUnknownGetter()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Unknown getter \'doesNotExit\''
+            'Unknown getter \'doesNotExit\'',
         ));
 
         /** @var mixed $interval */
@@ -86,6 +88,19 @@ class GettersTest extends AbstractTestCase
         $this->assertSame(10, $ci->seconds);
     }
 
+    public function testStartAndEnd()
+    {
+        $interval = Carbon::parse('2020-08-10')->diff('2020-09-30');
+
+        $this->assertSame('2020-08-10 00:00:00', $interval->start()->format('Y-m-d H:i:s'));
+        $this->assertSame('2020-09-30 00:00:00', $interval->end()->format('Y-m-d H:i:s'));
+
+        $interval = CarbonInterval::fromString('1 month 20 days');
+
+        $this->assertNull($interval->start());
+        $this->assertNull($interval->end());
+    }
+
     public function testDebugInfo()
     {
         $ci = CarbonInterval::create(4, 0, 6, 5, 0, 9, 10);
@@ -107,4 +122,23 @@ class GettersTest extends AbstractTestCase
             's' => 10,
         ], $ci->__debugInfo());
     }
+
+    public function testGetTimezone()
+    {
+        $this->assertNull(CarbonInterval::day()->tzName);
+        $this->assertSame(
+            'America/New_York',
+            CarbonInterval::day()->setTimezone('America/New_York')->tzName,
+        );
+        $this->assertSame(
+            'America/New_York',
+            CarbonInterval::day()->setTimezone(
+                new DateTimeZone('America/New_York'),
+            )->tzName,
+        );
+        $this->assertSame(
+            '+05:00',
+            CarbonInterval::day()->setTimezone(5)->tzName,
+        );
+    }
 }
