@@ -14,6 +14,7 @@ declare(strict_types=1);
 namespace Tests\CarbonInterval;
 
 use BadMethodCallException;
+use Carbon\Carbon;
 use Carbon\CarbonInterval;
 use InvalidArgumentException;
 use Tests\AbstractTestCase;
@@ -72,6 +73,27 @@ class SettersTest extends AbstractTestCase
         $this->assertSame(1, $ci->dayz);
         $ci->day(3);
         $this->assertSame(3, $ci->dayz);
+
+        $diff = (new Carbon('2024-07-15 00:00'))->diff('2024-08-12 23:15');
+
+        $this->assertSame('4 weeks 23 hours 15 minutes', $diff->forHumans());
+        $this->assertSame(PHP_VERSION_ID < 8_02_00 ? false : 28, $diff->days);
+        $this->assertSame(28, $diff->dayz);
+        $this->assertSame(28, $diff->d);
+
+        // Setting days to false has no effect
+        $diff->days(false);
+
+        $this->assertSame(PHP_VERSION_ID < 8_02_00 ? false : 28, $diff->days);
+        $this->assertSame(28, $diff->dayz);
+        $this->assertSame(28, $diff->d);
+
+        // Setting days to integer affects days and d, but not "days" (bolt-on by parent DateInterval class)
+        $diff->days(14);
+
+        $this->assertSame(PHP_VERSION_ID < 8_02_00 ? false : 28, $diff->days);
+        $this->assertSame(14, $diff->dayz);
+        $this->assertSame(14, $diff->d);
     }
 
     public function testHoursSetter()
@@ -180,10 +202,24 @@ class SettersTest extends AbstractTestCase
         $this->assertSame(0, $ci->invert);
     }
 
+    public function testAbsolute()
+    {
+        $ci = CarbonInterval::day();
+
+        $this->assertSame($ci, $ci->absolute());
+        $this->assertSame(1.0, $ci->totalDays);
+
+        $this->assertSame(1.0, $ci->invert()->absolute()->totalDays);
+        $this->assertSame(-1.0, $ci->invert()->absolute(false)->totalDays);
+
+        $this->assertSame(1.0, $ci->invert()->abs(true)->totalDays);
+        $this->assertSame(-1.0, $ci->invert()->abs(false)->totalDays);
+    }
+
     public function testInvalidSetter()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Unknown setter \'doesNotExit\''
+            'Unknown setter \'doesNotExit\'',
         ));
 
         /** @var mixed $ci */
@@ -194,21 +230,21 @@ class SettersTest extends AbstractTestCase
     public function testInvalidFluentSetter()
     {
         $this->expectExceptionObject(new BadMethodCallException(
-            'Unknown fluent setter \'doesNotExit\''
+            'Unknown fluent setter \'doesNotExist\'',
         ));
 
         /** @var mixed $ci */
         $ci = new CarbonInterval();
-        $ci->doesNotExit(123);
+        $ci->doesNotExist(123);
     }
 
     public function testInvalidStaticFluentSetter()
     {
         $this->expectExceptionObject(new BadMethodCallException(
-            'Unknown fluent constructor \'doesNotExit\''
+            'Unknown fluent constructor \'doesNotExist\'',
         ));
 
-        CarbonInterval::doesNotExit(123);
+        CarbonInterval::doesNotExist(123);
     }
 
     public function testLocale()
@@ -219,10 +255,47 @@ class SettersTest extends AbstractTestCase
         $this->assertSame('de', $interval->locale);
     }
 
-    public function testTimezone()
+    public function testShiftTimezone()
     {
         $interval = CarbonInterval::hour()->shiftTimezone('America/Toronto');
 
         $this->assertSame('America/Toronto', $interval->getSettings()['timezone']);
+
+        /** @var CarbonInterval $interval */
+        $interval = CarbonInterval::diff(
+            Carbon::parse('2020-02-02 20:20 Asia/Tokyo'),
+            Carbon::parse('2020-02-03 22:22 Europe/Madrid'),
+        )->shiftTimezone('America/Toronto');
+
+        $this->assertSame('America/Toronto', $interval->getSettings()['timezone']);
+        $this->assertSame('2020-02-02 20:20 America/Toronto', $interval->start()->format('Y-m-d H:i e'));
+        $this->assertSame('2020-02-03 22:22 America/Toronto', $interval->end()->format('Y-m-d H:i e'));
+    }
+
+    public function testSetTimezone()
+    {
+        /** @var CarbonInterval $interval */
+        $interval = CarbonInterval::hour()->setTimezone('America/Toronto');
+
+        $this->assertSame('America/Toronto', $interval->tzname);
+        $this->assertSame('America/Toronto', $interval->tz_name);
+        $this->assertSame('America/Toronto', $interval->getSettings()['timezone']);
+
+        /** @var CarbonInterval $interval */
+        $interval = CarbonInterval::diff(
+            Carbon::parse('2020-02-02 20:20 Asia/Tokyo'),
+            Carbon::parse('2020-02-03 22:22 Europe/Madrid'),
+        )->setTimezone('America/Toronto');
+
+        $this->assertSame('America/Toronto', $interval->getSettings()['timezone']);
+        $this->assertSame('2020-02-02 06:20 America/Toronto', $interval->start()->format('Y-m-d H:i e'));
+        $this->assertSame('2020-02-03 16:22 America/Toronto', $interval->end()->format('Y-m-d H:i e'));
+
+        /** @var CarbonInterval $interval */
+        $interval = CarbonInterval::hour();
+        $next = $interval->set(' * foobar', 'biz');
+
+        $this->assertSame($next, $interval);
+        $this->assertSame('1 hour', $interval->forHumans());
     }
 }
