@@ -24,92 +24,114 @@ class AliasTest extends AbstractTestCase
 {
     public function testSetStartDate()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::start($date = '2017-09-13 12:30:45', false);
         $this->assertEquals(Carbon::parse($date), $period->getStartDate());
-        $this->assertEquals(Carbon::parse($date), $period->start);
-        $this->assertSame($periodClass::EXCLUDE_START_DATE, $period->getOptions());
+        $this->assertEquals(Carbon::parse($date), $period->start());
+
+        if (PHP_VERSION < 8.2) {
+            $this->assertEquals(Carbon::parse($date), $period->start);
+        }
+
+        $this->assertPeriodOptions($periodClass::EXCLUDE_START_DATE, $period);
 
         $period = $period->since($date = '2014-10-12 15:42:34', true);
         $this->assertEquals(Carbon::parse($date), $period->getStartDate());
-        $this->assertEmpty($period->getOptions());
+        $this->assertPeriodOptions(0, $period);
 
         $period = $period->sinceNow(false);
         $this->assertEquals(Carbon::now(), $period->getStartDate());
-        $this->assertSame($periodClass::EXCLUDE_START_DATE, $period->getOptions());
+        $this->assertPeriodOptions($periodClass::EXCLUDE_START_DATE, $period);
     }
 
-    /**
-     * @requires PHP >= 8.0
-     */
     public function testSetStartDateWithNamedParameters()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $date = '2017-09-13 12:30:45';
-        $period = eval('return \\'.$periodClass.'::start(date: $date, inclusive: false);');
+        /** @var CarbonPeriod $period */
+        $period = $periodClass::start(date: $date, inclusive: false);
         $this->assertEquals(Carbon::parse($date), $period->getStartDate());
-        $this->assertEquals(Carbon::parse($date), $period->start);
-        $this->assertSame(CarbonPeriod::EXCLUDE_START_DATE, $period->getOptions());
+        $this->assertEquals(Carbon::parse($date), $period->start());
 
-        $period = eval('return \\'.$periodClass.'::start(date: $date);');
+        if (PHP_VERSION < 8.2) {
+            $this->assertEquals(Carbon::parse($date), $period->start);
+        }
+
+        $this->assertPeriodOptions(CarbonPeriod::EXCLUDE_START_DATE, $period);
+
+        /** @var CarbonPeriod $period */
+        $period = $periodClass::start(date: $date);
         $this->assertEquals(Carbon::parse($date), $period->getStartDate());
-        $this->assertEquals(Carbon::parse($date), $period->start);
-        $this->assertEmpty($period->getOptions());
+        $this->assertEquals(Carbon::parse($date), $period->start());
+
+        if (PHP_VERSION < 8.2) {
+            $this->assertEquals(Carbon::parse($date), $period->start);
+        }
+
+        $this->assertPeriodOptions(0, $period);
 
         $date = '2014-10-12 15:42:34';
-        $period = eval('return $period->since(date: $date, inclusive: true);');
+        $period = $period->since(date: $date, inclusive: true);
         $this->assertEquals(Carbon::parse($date), $period->getStartDate());
-        $this->assertEmpty($period->getOptions());
+        $this->assertPeriodOptions(0, $period);
 
-        $period = eval('return $period->sinceNow(inclusive: false);');
+        $period = $period->sinceNow(inclusive: false);
         $this->assertEquals(Carbon::now(), $period->getStartDate());
-        $this->assertSame($periodClass::EXCLUDE_START_DATE, $period->getOptions());
+        $this->assertPeriodOptions($periodClass::EXCLUDE_START_DATE, $period);
 
         $period = $periodClass::sinceNow();
         $this->assertEquals(Carbon::now(), $period->getStartDate());
-        $this->assertEmpty($period->getOptions());
+        $this->assertPeriodOptions(0, $period);
     }
 
     public function testSetEndDate()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::end($date = '2017-09-13 12:30:45', false);
         $this->assertEquals(Carbon::parse($date), $period->getEndDate());
-        $this->assertEquals(Carbon::parse($date), $period->end);
-        $this->assertSame($periodClass::EXCLUDE_END_DATE, $period->getOptions());
+        $this->assertEquals(Carbon::parse($date), $period->end());
+
+        if (PHP_VERSION < 8.2) {
+            $this->assertEquals(Carbon::parse($date), $period->end);
+        }
+
+        $this->assertPeriodOptions(CarbonPeriod::EXCLUDE_END_DATE, $period);
 
         $period = $period->until($date = '2014-10-12 15:42:34', true);
         $this->assertEquals(Carbon::parse($date), $period->getEndDate());
-        $this->assertEmpty($period->getOptions());
+        $this->assertPeriodOptions(0, $period);
 
         $period = $period->untilNow(false);
         $this->assertEquals(Carbon::now(), $period->getEndDate());
-        $this->assertSame($periodClass::EXCLUDE_END_DATE, $period->getOptions());
+        $this->assertPeriodOptions($periodClass::EXCLUDE_END_DATE, $period);
 
-        $period = $period->end();
+        $period = $period->end(null);
         $this->assertNull($period->getEndDate());
     }
 
-    /**
-     * @requires PHP >= 8.0
-     */
     public function testSetEndDateWithNamedParameters()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $date = '2017-09-13 12:30:45';
-        $period = eval('return \\'.$periodClass.'::end(date: $date, inclusive: false);');
+        /** @var CarbonPeriod $period */
+        $period = $periodClass::end(date: $date, inclusive: false);
         $this->assertEquals(Carbon::parse($date), $period->getEndDate());
-        $this->assertEquals(Carbon::parse($date), $period->end);
-        $this->assertSame($periodClass::EXCLUDE_END_DATE, $period->getOptions());
+        $this->assertEquals(Carbon::parse($date), $period->end());
+
+        if (PHP_VERSION < 8.2) {
+            $this->assertEquals(Carbon::parse($date), $period->end);
+        }
+
+        $this->assertPeriodOptions(CarbonPeriod::EXCLUDE_END_DATE, $period);
 
         $date = '2014-10-12 15:42:34';
-        $period = eval('return $period->until(date: $date, inclusive: true);');
+        $period = $period->until(date: $date, inclusive: true);
         $this->assertEquals(Carbon::parse($date), $period->getEndDate());
-        $this->assertEmpty($period->getOptions());
+        $this->assertPeriodOptions(0, $period);
 
-        $period = eval('return $period->untilNow(inclusive: false);');
+        $period = $period->untilNow(inclusive: false);
         $this->assertEquals(Carbon::now(), $period->getEndDate());
-        $this->assertSame($periodClass::EXCLUDE_END_DATE, $period->getOptions());
+        $this->assertPeriodOptions($periodClass::EXCLUDE_END_DATE, $period);
     }
 
     public function testManageFilters()
@@ -118,9 +140,10 @@ class AliasTest extends AbstractTestCase
             return true;
         };
 
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::filter($filter, 'foo');
         $this->assertSame([[$filter, 'foo']], $period->getFilters());
+        $this->assertSame([[$filter, 'foo']], $period->filters());
 
         $period = $period->push($filter, 'bar');
         $this->assertSame([[$filter, 'foo'], [$filter, 'bar']], $period->getFilters());
@@ -128,8 +151,8 @@ class AliasTest extends AbstractTestCase
         $period = $period->prepend($filter, 'pre');
         $this->assertSame([[$filter, 'pre'], [$filter, 'foo'], [$filter, 'bar']], $period->getFilters());
 
-        $period = $period->filters();
-        $this->assertEmpty($period->getFilters());
+        $period = $period->filters([]);
+        $this->assertSame([], $period->getFilters());
 
         $period = $period->filters($filters = [[$filter, null]]);
         $this->assertSame($filters, $period->getFilters());
@@ -137,21 +160,25 @@ class AliasTest extends AbstractTestCase
 
     public function testSetRecurrences()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::recurrences(5);
         $this->assertSame(5, $period->getRecurrences());
-        $this->assertSame(5, $period->recurrences);
+        $this->assertSame(5, $period->recurrences());
+
+        if (PHP_VERSION < 8.2) {
+            $this->assertSame(5, $period->recurrences);
+        }
 
         $period = $period->times(3);
         $this->assertSame(3, $period->getRecurrences());
 
-        $period = $period->recurrences();
+        $period = $period->recurrences(null);
         $this->assertNull($period->getRecurrences());
     }
 
     public function testManageOptions()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $start = $periodClass::EXCLUDE_START_DATE;
         $end = $periodClass::EXCLUDE_END_DATE;
 
@@ -163,14 +190,15 @@ class AliasTest extends AbstractTestCase
 
         $period = $period->toggle($end, false);
         $this->assertSame($start, $period->getOptions());
+        $this->assertSame($start, $period->options());
 
-        $period = $period->options();
-        $this->assertEmpty($period->getOptions());
+        $period = $period->options(null);
+        $this->assertSame(0, $period->getOptions());
     }
 
     public function testSetDates()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::dates($start = '2014-10-12 15:42:34', $end = '2017-09-13 12:30:45');
         $this->assertEquals(Carbon::parse($start), $period->getStartDate());
         $this->assertEquals(Carbon::parse($end), $period->getEndDate());
@@ -182,22 +210,29 @@ class AliasTest extends AbstractTestCase
 
     public function testManageInterval()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::interval('PT6H');
-        $this->assertEquals(CarbonInterval::create('PT6H'), $period->getDateInterval());
-        $this->assertEquals(CarbonInterval::create('PT6H'), $period->interval);
+        $this->assertEquals(CarbonInterval::create('PT6H')->optimize(), $period->getDateInterval()->optimize());
+        $this->assertEquals(CarbonInterval::create('PT6H')->optimize(), $period->interval()->optimize());
+
+        if (PHP_VERSION < 8.2) {
+            $this->assertEquals(CarbonInterval::create('PT6H')->optimize(), $period->interval->optimize());
+        }
     }
 
     public function testInvertInterval()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::invert();
-        $this->assertEquals(CarbonInterval::create('P1D')->invert(), $period->getDateInterval());
+        $this->assertEquals(
+            CarbonInterval::create('P1D')->invert()->optimize(),
+            $period->getDateInterval()->optimize(),
+        );
     }
 
     public function testModifyIntervalPlural()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::weeks(2);
         $this->assertSame('P14D', $period->getDateInterval()->spec());
 
@@ -206,11 +241,23 @@ class AliasTest extends AbstractTestCase
 
         $period = $period->years(0)->months(0)->dayz(0)->hours(0)->minutes(0)->seconds(1);
         $this->assertSame('PT1S', $period->getDateInterval()->spec());
+
+        $period = $periodClass::create();
+        $this->assertSame('P1D', $period->getDateInterval()->spec());
+
+        $period = $periodClass::create()->hours(12);
+        $this->assertSame('PT12H', $period->getDateInterval()->spec());
+
+        $period = $periodClass::day()->hours(12);
+        $this->assertSame('P1DT12H', $period->getDateInterval()->spec());
+
+        $period = $periodClass::day()->resetDateInterval()->hours(12);
+        $this->assertSame('PT12H', $period->getDateInterval()->spec());
     }
 
     public function testModifyIntervalSingular()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::week();
         $this->assertSame('P7D', $period->getDateInterval()->spec());
 
@@ -223,7 +270,7 @@ class AliasTest extends AbstractTestCase
 
     public function testChainAliases()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         Carbon::setTestNow('2018-05-15');
         $period = $periodClass::days(3)->hours(5)->invert()
             ->sinceNow()->until(Carbon::now()->subDays(10))
@@ -234,23 +281,23 @@ class AliasTest extends AbstractTestCase
             $this->standardizeDates([
                 Carbon::now()->subDays(3)->subHours(5), Carbon::now()->subDays(6)->subHours(10),
             ]),
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
     }
 
     public function testCallInvalidAlias()
     {
         $this->expectExceptionObject(new BadMethodCallException(
-            'Method foobar does not exist.'
+            'Method foobar does not exist.',
         ));
 
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $periodClass::foobar();
     }
 
     public function testOverrideDefaultInterval()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::hours(5);
         $this->assertSame('PT5H', $period->getDateInterval()->spec());
 
@@ -264,60 +311,57 @@ class AliasTest extends AbstractTestCase
     public function testModifyIntoEmptyDateInterval()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Empty interval is not accepted.'
+            'Empty interval is not accepted.',
         ));
 
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $periodClass::days(0);
     }
 
-    /**
-     * @requires PHP >= 8.0
-     */
     public function testNamedParameters()
     {
-        $periodClass = $this->periodClass;
-        $period = eval("return \\$periodClass::between(start: '2022-09-13', end: '2022-10-12');");
+        $periodClass = static::$periodClass;
+        $period = $periodClass::between(start: '2022-09-13', end: '2022-10-12');
         $this->assertEquals('2022-09-13', $period->getStartDate()->format('Y-m-d'));
         $this->assertEquals('2022-10-12', $period->getEndDate()->format('Y-m-d'));
 
-        $period = eval('return $period->years(years: 5);');
+        $period = $period->years(years: 5);
         $this->assertEquals('5 years', (string) $period->getDateInterval());
 
-        $period = eval('return $period->interval(interval: \Carbon\CarbonInterval::year(years: 3));');
+        $period = $period->interval(interval: \Carbon\CarbonInterval::year(years: 3));
         $this->assertEquals('3 years', (string) $period->getDateInterval());
 
-        $period = eval("return \\$periodClass::between(start: '2022-09-13', end: '2022-10-12')->months(months: 5);");
+        $period = $periodClass::between(start: '2022-09-13', end: '2022-10-12')->months(months: 5);
         $this->assertEquals('5 months', (string) $period->getDateInterval());
 
-        $period = eval("return \\$periodClass::between(start: '2022-09-13', end: '2022-10-12')->weeks(weeks: 5);");
+        $period = $periodClass::between(start: '2022-09-13', end: '2022-10-12')->weeks(weeks: 5);
         $this->assertEquals('5 weeks', (string) $period->getDateInterval());
 
-        $period = eval("return \\$periodClass::between(start: '2022-09-13', end: '2022-10-12')->days(days: 5);");
+        $period = $periodClass::between(start: '2022-09-13', end: '2022-10-12')->days(days: 5);
         $this->assertEquals('5 days', (string) $period->getDateInterval());
 
-        $period = eval("return \\$periodClass::between(start: '2022-09-13', end: '2022-10-12')->hours(hours: 5);");
+        $period = $periodClass::between(start: '2022-09-13', end: '2022-10-12')->hours(hours: 5);
         $this->assertEquals('5 hours', (string) $period->getDateInterval());
 
-        $period = eval("return \\$periodClass::between(start: '2022-09-13', end: '2022-10-12')->minutes(minutes: 5);");
+        $period = $periodClass::between(start: '2022-09-13', end: '2022-10-12')->minutes(minutes: 5);
         $this->assertEquals('5 minutes', (string) $period->getDateInterval());
 
-        $period = eval("return \\$periodClass::between(start: '2022-09-13', end: '2022-10-12')->seconds(seconds: 5);");
+        $period = $periodClass::between(start: '2022-09-13', end: '2022-10-12')->seconds(seconds: 5);
         $this->assertEquals('5 seconds', (string) $period->getDateInterval());
 
-        $period = eval("return \\$periodClass::between(start: '2022-09-13', end: '2022-10-12')
+        $period = $periodClass::between(start: '2022-09-13', end: '2022-10-12')
             ->days(days: 5)
-            ->floorDays(precision: 2);");
+            ->floorDays(precision: 2);
         $this->assertEquals('4 days', (string) $period->getDateInterval());
 
-        $period = eval("return \\$periodClass::between(start: '2022-09-13', end: '2022-10-12')
+        $period = $periodClass::between(start: '2022-09-13', end: '2022-10-12')
             ->days(days: 5)
-            ->roundDays(precision: 7);");
+            ->roundDays(precision: 7);
         $this->assertEquals('1 week', (string) $period->getDateInterval());
 
-        $period = eval("return \\$periodClass::between(start: '2022-09-13', end: '2022-10-12')
+        $period = $periodClass::between(start: '2022-09-13', end: '2022-10-12')
             ->days(days: 5)
-            ->ceilDays(precision: 2);");
+            ->ceilDays(precision: 2);
         $this->assertEquals('6 days', (string) $period->getDateInterval());
     }
 }
