@@ -16,33 +16,38 @@ namespace Tests\CarbonPeriod;
 use BadMethodCallException;
 use Carbon\Carbon;
 use Carbon\CarbonImmutable;
+use Carbon\CarbonInterface;
 use Carbon\CarbonInterval;
 use Carbon\CarbonPeriod;
 use Carbon\CarbonPeriodImmutable;
+use Carbon\Exceptions\InvalidPeriodParameterException;
 use Carbon\Exceptions\NotAPeriodException;
+use Carbon\Month;
+use Carbon\Unit;
 use DateInterval;
 use DatePeriod;
 use DateTime;
 use Generator;
 use InvalidArgumentException;
+use PHPUnit\Framework\Attributes\DataProvider;
 use stdClass;
 use Tests\AbstractTestCase;
 
 class CreateTest extends AbstractTestCase
 {
-    /**
-     * @dataProvider \Tests\CarbonPeriod\CreateTest::dataForIso8601String
-     */
+    #[DataProvider('dataForIso8601String')]
     public function testCreateFromIso8601String($arguments, $expected)
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         [$iso, $options] = array_pad($arguments, 2, null);
 
         $period = $periodClass::create($iso, $options);
 
+        $this->assertInstanceOf(CarbonPeriod::class, $period);
+        $this->assertInstanceOf(DatePeriod::class, $period);
         $this->assertSame(
             $this->standardizeDates($expected),
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
     }
 
@@ -72,7 +77,7 @@ class CreateTest extends AbstractTestCase
 
     public function testCreateFromIso8601StringWithUnboundedRecurrences()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::create('R/2012-07-01T00:00:00/P7D');
 
         $this->assertSame('2012-07-01', $period->getStartDate()->toDateString());
@@ -83,7 +88,7 @@ class CreateTest extends AbstractTestCase
 
     public function testCreateFromIso8601StringWithInfiniteRecurrences()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::create('RINF/2012-07-01T00:00:00/P7D');
         $this->assertSame('2012-07-01', $period->getStartDate()->toDateString());
         $this->assertSame('P7D', $period->getDateInterval()->spec());
@@ -91,24 +96,22 @@ class CreateTest extends AbstractTestCase
         $this->assertInfinite($period->getRecurrences());
     }
 
-    /**
-     * @dataProvider \Tests\CarbonPeriod\CreateTest::dataForPartialIso8601String
-     */
+    #[DataProvider('dataForPartialIso8601String')]
     public function testCreateFromPartialIso8601String($iso, $from, $to)
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::create($iso);
 
         $this->assertSame(
             $this->standardizeDates([$from, $to]),
-            $this->standardizeDates([$period->getStartDate(), $period->getEndDate()])
+            $this->standardizeDates([$period->getStartDate(), $period->getEndDate()]),
         );
 
         $period = new $periodClass($iso);
 
         $this->assertSame(
             $this->standardizeDates([$from, $to]),
-            $this->standardizeDates([$period->getStartDate(), $period->getEndDate()])
+            $this->standardizeDates([$period->getStartDate(), $period->getEndDate()]),
         );
     }
 
@@ -118,16 +121,14 @@ class CreateTest extends AbstractTestCase
         yield ['2007-12-14T13:30/15:30', '2007-12-14 13:30', '2007-12-14 15:30'];
     }
 
-    /**
-     * @dataProvider \Tests\CarbonPeriod\CreateTest::dataForInvalidIso8601String
-     */
+    #[DataProvider('dataForInvalidIso8601String')]
     public function testCreateFromInvalidIso8601String($iso)
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            "Invalid ISO 8601 specification: $iso"
+            "Invalid ISO 8601 specification: $iso",
         ));
 
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $periodClass::create($iso);
     }
 
@@ -141,12 +142,10 @@ class CreateTest extends AbstractTestCase
         yield ['/'];
     }
 
-    /**
-     * @dataProvider \Tests\CarbonPeriod\CreateTest::dataForStartDateAndEndDate
-     */
+    #[DataProvider('dataForStartDateAndEndDate')]
     public function testCreateFromStartDateAndEndDate($arguments, $expected)
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         [$start, $end, $options] = array_pad($arguments, 3, null);
 
         $start = Carbon::parse($start);
@@ -156,7 +155,7 @@ class CreateTest extends AbstractTestCase
 
         $this->assertSame(
             $this->standardizeDates($expected),
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
     }
 
@@ -196,12 +195,10 @@ class CreateTest extends AbstractTestCase
             ];
     }
 
-    /**
-     * @dataProvider \Tests\CarbonPeriod\CreateTest::dataForStartDateAndIntervalAndEndDate
-     */
+    #[DataProvider('dataForStartDateAndIntervalAndEndDate')]
     public function testCreateFromStartDateAndIntervalAndEndDate($arguments, $expected)
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         [$start, $interval, $end, $options] = array_pad($arguments, 4, null);
 
         $start = Carbon::parse($start);
@@ -212,7 +209,7 @@ class CreateTest extends AbstractTestCase
 
         $this->assertSame(
             $this->standardizeDates($expected),
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
     }
 
@@ -257,12 +254,10 @@ class CreateTest extends AbstractTestCase
         ];
     }
 
-    /**
-     * @dataProvider \Tests\CarbonPeriod\CreateTest::dataForStartDateAndIntervalAndRecurrences
-     */
+    #[DataProvider('dataForStartDateAndIntervalAndRecurrences')]
     public function testCreateFromStartDateAndIntervalAndRecurrences($arguments, $expected)
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         [$start, $interval, $recurrences, $options] = array_pad($arguments, 4, null);
 
         $start = Carbon::parse($start);
@@ -272,7 +267,7 @@ class CreateTest extends AbstractTestCase
 
         $this->assertSame(
             $this->standardizeDates($expected),
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
     }
 
@@ -288,12 +283,10 @@ class CreateTest extends AbstractTestCase
         ];
     }
 
-    /**
-     * @dataProvider \Tests\CarbonPeriod\CreateTest::dataForStartDateAndRecurrences
-     */
+    #[DataProvider('dataForStartDateAndRecurrences')]
     public function testCreateFromStartDateAndRecurrences($arguments, $expected)
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         [$start, $recurrences, $options] = array_pad($arguments, 4, null);
 
         $start = Carbon::parse($start);
@@ -302,7 +295,7 @@ class CreateTest extends AbstractTestCase
 
         $this->assertSame(
             $this->standardizeDates($expected),
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
     }
 
@@ -328,11 +321,11 @@ class CreateTest extends AbstractTestCase
 
     public function testCreateFromBaseClasses()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::create(
             new DateTime('2018-04-16'),
             new DateInterval('P1M'),
-            new DateTime('2018-07-15')
+            new DateTime('2018-07-15'),
         );
 
         $this->assertSame(
@@ -341,20 +334,18 @@ class CreateTest extends AbstractTestCase
                 '2018-05-16 00:00:00 -04:00',
                 '2018-06-16 00:00:00 -04:00',
             ],
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
     }
 
-    /**
-     * @dataProvider \Tests\CarbonPeriod\CreateTest::dataForInvalidParameters
-     */
+    #[DataProvider('dataForInvalidParameters')]
     public function testCreateFromInvalidParameters(...$arguments)
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'Invalid constructor parameters.'
+            'Invalid constructor parameters.',
         ));
 
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $periodClass::create(...$arguments);
     }
 
@@ -371,11 +362,11 @@ class CreateTest extends AbstractTestCase
 
     public function testCreateOnDstForwardChange()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::create(
             '2018-03-25 1:30 Europe/Oslo',
             'PT30M',
-            '2018-03-25 3:30 Europe/Oslo'
+            '2018-03-25 3:30 Europe/Oslo',
         );
 
         $this->assertSame(
@@ -384,7 +375,7 @@ class CreateTest extends AbstractTestCase
                 '2018-03-25 03:00:00 +02:00',
                 '2018-03-25 03:30:00 +02:00',
             ],
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
     }
 
@@ -398,11 +389,11 @@ class CreateTest extends AbstractTestCase
      */
     public function testCreateOnDstBackwardChange()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::create(
             '2018-10-28 1:30 Europe/Oslo',
             'PT30M',
-            '2018-10-28 3:30 Europe/Oslo'
+            '2018-10-28 3:30 Europe/Oslo',
         );
 
         $this->assertSame(
@@ -415,17 +406,17 @@ class CreateTest extends AbstractTestCase
                 '2018-10-28 03:00:00 +01:00',
                 '2018-10-28 03:30:00 +01:00',
             ],
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
     }
 
     public function testInternalVariablesCannotBeIndirectlyModified()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::create(
             $start = new DateTime('2018-04-16'),
             $interval = new DateInterval('P1M'),
-            $end = new DateTime('2018-07-15')
+            $end = new DateTime('2018-07-15'),
         );
 
         $start->modify('-5 days');
@@ -439,7 +430,7 @@ class CreateTest extends AbstractTestCase
         $period = $periodClass::create(
             $start = new Carbon('2018-04-16'),
             $interval = new CarbonInterval('P1M'),
-            $end = new Carbon('2018-07-15')
+            $end = new Carbon('2018-07-15'),
         );
 
         $start->subDays(5);
@@ -453,7 +444,7 @@ class CreateTest extends AbstractTestCase
 
     public function testCreateFromArray()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::createFromArray([
             '2018-03-25', 'P2D', '2018-04-01', $periodClass::EXCLUDE_END_DATE,
         ]);
@@ -461,77 +452,108 @@ class CreateTest extends AbstractTestCase
         $this->assertSame('2018-03-25', $period->getStartDate()->toDateString());
         $this->assertSame('P2D', $period->getDateInterval()->spec());
         $this->assertSame('2018-04-01', $period->getEndDate()->toDateString());
-        $this->assertSame($periodClass::EXCLUDE_END_DATE, $period->getOptions());
+        $this->assertPeriodOptions($periodClass::EXCLUDE_END_DATE, $period);
     }
 
     public function testCreateFromIso()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::createFromIso('R3/2018-03-25/P2D/2018-04-01', $periodClass::EXCLUDE_END_DATE);
 
         $this->assertSame('2018-03-25', $period->getStartDate()->toDateString());
         $this->assertSame('P2D', $period->getDateInterval()->spec());
         $this->assertSame('2018-04-01', $period->getEndDate()->toDateString());
         $this->assertSame(3, $period->getRecurrences());
-        $this->assertSame($periodClass::EXCLUDE_END_DATE, $period->getOptions());
+        $this->assertPeriodOptions($periodClass::EXCLUDE_END_DATE, $period);
     }
 
     public function testCreateEmpty()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = new $periodClass();
 
         $this->assertEquals(new Carbon(), $period->getStartDate());
         $this->assertSame('P1D', $period->getDateInterval()->spec());
         $this->assertNull($period->getEndDate());
         $this->assertNull($period->getRecurrences());
-        $this->assertSame(0, $period->getOptions());
+        $this->assertPeriodOptions(0, $period);
     }
 
     public function testCreateFromDateStringsWithTimezones()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
+        $periodClass = \Carbon\CarbonPeriodImmutable::class;
         $period = $periodClass::create(
             $start = '2018-03-25 10:15:30 Europe/Oslo',
-            $end = '2018-03-28 17:25:30 Asia/Kamchatka'
+            $end = '2018-03-28 17:25:30 Asia/Kamchatka',
         );
 
+        $this->assertSame('2018-03-25 10:15:30 Europe/Oslo', $period->first()->format('Y-m-d H:i:s e'));
+        $this->assertSame('2018-03-27 10:15:30 Europe/Oslo', $period->last()->format('Y-m-d H:i:s e'));
         $this->assertSame($start, $period->getStartDate()->format('Y-m-d H:i:s e'));
         $this->assertSame($end, $period->getEndDate()->format('Y-m-d H:i:s e'));
+
+        $period = $periodClass::create(
+            '2024-01-01',
+            '2024-01-05',
+            \Carbon\CarbonTimeZone::create('Australia/Melbourne'),
+        );
+        $this->assertSame('Australia/Melbourne', $period->first()->timezone->getName());
+        $this->assertSame('Australia/Melbourne', $period->last()->timezone->getName());
+        $this->assertSame('Australia/Melbourne', $period->getStartDate()->timezone->getName());
+        $this->assertSame('Australia/Melbourne', $period->getEndDate()->timezone->getName());
+        $this->assertSame('2024-01-01 00:00:00 Australia/Melbourne', $period->first()->format('Y-m-d H:i:s e'));
+        $this->assertSame('2024-01-05 00:00:00 Australia/Melbourne', $period->last()->format('Y-m-d H:i:s e'));
+        $this->assertSame('2024-01-01 00:00:00 Australia/Melbourne', $period->getStartDate()->format('Y-m-d H:i:s e'));
+        $this->assertSame('2024-01-05 00:00:00 Australia/Melbourne', $period->getEndDate()->format('Y-m-d H:i:s e'));
+
+        $period = $periodClass::create(
+            '2024-01-01',
+            '2024-01-05',
+            'Australia/Melbourne',
+        );
+        $this->assertSame('Australia/Melbourne', $period->first()->timezone->getName());
+        $this->assertSame('Australia/Melbourne', $period->last()->timezone->getName());
+        $this->assertSame('Australia/Melbourne', $period->getStartDate()->timezone->getName());
+        $this->assertSame('Australia/Melbourne', $period->getEndDate()->timezone->getName());
+        $this->assertSame('2024-01-01 00:00:00 Australia/Melbourne', $period->first()->format('Y-m-d H:i:s e'));
+        $this->assertSame('2024-01-05 00:00:00 Australia/Melbourne', $period->last()->format('Y-m-d H:i:s e'));
+        $this->assertSame('2024-01-01 00:00:00 Australia/Melbourne', $period->getStartDate()->format('Y-m-d H:i:s e'));
+        $this->assertSame('2024-01-05 00:00:00 Australia/Melbourne', $period->getEndDate()->format('Y-m-d H:i:s e'));
     }
 
     public function testCreateWithIntervalInFromStringFormat()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::create(
             '2018-03-25 12:00',
             '2 days 10 hours',
-            '2018-04-01 13:30'
+            '2018-04-01 13:30',
         );
 
         $this->assertSame(
             $this->standardizeDates(['2018-03-25 12:00', '2018-03-27 22:00', '2018-03-30 08:00']),
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
 
         $period = $periodClass::create(
             '2018-04-21',
             '3 days',
-            '2018-04-27'
+            '2018-04-27',
         );
 
         $this->assertSame(
             $this->standardizeDates(['2018-04-21 00:00', '2018-04-24 00:00', '2018-04-27 00:00']),
-            $this->standardizeDates($period)
+            $this->standardizeDates($period),
         );
     }
 
     public function testCreateFromRelativeDates()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::create(
             $start = 'previous friday',
-            $end = '+6 days'
+            $end = '+6 days',
         );
 
         $this->assertEquals(new Carbon($start), $period->getStartDate());
@@ -540,9 +562,19 @@ class CreateTest extends AbstractTestCase
 
     public function testCreateFromCarbonInstances()
     {
+        $date1 = Carbon::parse('2018-06-01');
+        $date2 = Carbon::parse('2018-06-10');
+        $period = $date1->toPeriod($date2, 'P1D');
+
+        $this->assertSame(24.0, $period->getDateInterval()->totalHours);
+        $this->assertInstanceOf(Carbon::class, $period->getStartDate());
+        $this->assertSame('2018-06-01', $period->getStartDate()->format('Y-m-d'));
+        $this->assertInstanceOf(Carbon::class, $period->getEndDate());
+        $this->assertSame('2018-06-10', $period->getEndDate()->format('Y-m-d'));
+
         $period = Carbon::create('2019-01-02')->toPeriod(7);
 
-        $this->assertSame(24, $period->getDateInterval()->totalHours);
+        $this->assertSame(24.0, $period->getDateInterval()->totalHours);
         $this->assertInstanceOf(Carbon::class, $period->getStartDate());
         $this->assertSame('2019-01-02', $period->getStartDate()->format('Y-m-d'));
         $this->assertNull($period->getEndDate());
@@ -554,7 +586,7 @@ class CreateTest extends AbstractTestCase
         $period = Carbon::create('2019-01-02')->toPeriod('2019-02-05');
 
         $this->assertNull($period->getRecurrences());
-        $this->assertSame(24, $period->getDateInterval()->totalHours);
+        $this->assertSame(24.0, $period->getDateInterval()->totalHours);
         $this->assertInstanceOf(Carbon::class, $period->getStartDate());
         $this->assertSame('2019-01-02', $period->getStartDate()->format('Y-m-d'));
         $this->assertInstanceOf(Carbon::class, $period->getEndDate());
@@ -569,7 +601,7 @@ class CreateTest extends AbstractTestCase
 
         $period = Carbon::create('2019-01-02')->daysUntil('2019-02-05');
 
-        $this->assertSame(24, $period->getDateInterval()->totalHours);
+        $this->assertSame(24.0, $period->getDateInterval()->totalHours);
         $this->assertInstanceOf(Carbon::class, $period->getStartDate());
         $this->assertSame('2019-01-02', $period->getStartDate()->format('Y-m-d'));
         $this->assertInstanceOf(Carbon::class, $period->getEndDate());
@@ -591,14 +623,14 @@ class CreateTest extends AbstractTestCase
         $this->assertSame('2019-02-05', $period->getEndDate()->format('Y-m-d'));
 
         $period = Carbon::create('2019-01-02')->hoursUntil('2019-02-05');
-        $this->assertSame(1, $period->getDateInterval()->totalHours);
+        $this->assertSame(1.0, $period->getDateInterval()->totalHours);
 
         $this->assertSame('1 minute', Carbon::create('2019-01-02')->minutesUntil('2019-02-05')->getDateInterval()->forHumans());
         $this->assertSame('3 minutes', Carbon::create('2019-01-02')->minutesUntil('2019-02-05', 3)->getDateInterval()->forHumans());
         $this->assertSame('3 seconds', Carbon::create('2019-01-02')->range('2019-02-05', 3, 'seconds')->getDateInterval()->forHumans());
         $this->assertSame('1 second', Carbon::create('2019-01-02')->secondsUntil('2019-02-05')->getDateInterval()->forHumans());
-        $this->assertSame(1, Carbon::create('2019-01-02')->millisecondsUntil('2019-02-05')->getDateInterval()->totalMilliseconds);
-        $this->assertSame(1, Carbon::create('2019-01-02')->microsecondsUntil('2019-02-05')->getDateInterval()->totalMicroseconds);
+        $this->assertSame(1.0, Carbon::create('2019-01-02')->millisecondsUntil('2019-02-05')->getDateInterval()->totalMilliseconds);
+        $this->assertSame(1.0, Carbon::create('2019-01-02')->microsecondsUntil('2019-02-05')->getDateInterval()->totalMicroseconds);
         $this->assertSame('1 week', Carbon::create('2019-01-02')->weeksUntil('2019-02-05')->getDateInterval()->forHumans());
         $this->assertSame('1 month', Carbon::create('2019-01-02')->monthsUntil('2019-02-05')->getDateInterval()->forHumans());
         $this->assertSame('3 months', Carbon::create('2019-01-02')->quartersUntil('2019-02-05')->getDateInterval()->forHumans());
@@ -611,7 +643,7 @@ class CreateTest extends AbstractTestCase
     public function testCreateFromCarbonInstanceInvalidMethod()
     {
         $this->expectExceptionObject(new BadMethodCallException(
-            'Method unknownUnitsUntil does not exist.'
+            'Method unknownUnitsUntil does not exist.',
         ));
 
         /** @var object $date */
@@ -621,11 +653,11 @@ class CreateTest extends AbstractTestCase
 
     public function testInstance()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $source = new DatePeriod(
             new DateTime('2012-07-01'),
             CarbonInterval::days(2),
-            new DateTime('2012-07-07')
+            new DateTime('2012-07-07'),
         );
 
         $period = $periodClass::instance($source);
@@ -660,22 +692,19 @@ class CreateTest extends AbstractTestCase
         $this->assertNotSame($period, $period4);
     }
 
-    /**
-     * @requires PHP >= 8.0
-     */
     public function testCreateFromCarbonInstancesNamedParameters()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $carbonClass = $periodClass === CarbonPeriodImmutable::class
             ? CarbonImmutable::class
             : Carbon::class;
-        $period = eval("return \\$carbonClass::create('2019-01-02')->daysUntil(endDate: '2019-02-05');");
+        $period = $carbonClass::create('2019-01-02')->daysUntil(endDate: '2019-02-05');
         $this->assertInstanceOf($periodClass, $period);
         $this->assertSame('2019-01-02', $period->getStartDate()->format('Y-m-d'));
         $this->assertSame('2019-02-05', $period->getEndDate()->format('Y-m-d'));
         $this->assertSame('1 day', (string) $period->getDateInterval());
 
-        $period = eval("return \\$carbonClass::create('2019-01-02')->hoursUntil(endDate: '2019-02-05', factor: 12);");
+        $period = $carbonClass::create('2019-01-02')->hoursUntil(endDate: '2019-02-05', factor: 12);
         $this->assertInstanceOf($periodClass, $period);
         $this->assertSame('2019-01-02', $period->getStartDate()->format('Y-m-d'));
         $this->assertSame('2019-02-05', $period->getEndDate()->format('Y-m-d'));
@@ -684,7 +713,7 @@ class CreateTest extends AbstractTestCase
 
     public function testCast()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass === CarbonPeriodImmutable::class
             ? (new class('2012-07-01', CarbonInterval::days(2), '2012-07-07') extends CarbonPeriodImmutable {
                 public function foo()
@@ -719,21 +748,21 @@ class CreateTest extends AbstractTestCase
     public function testBadCast()
     {
         $this->expectExceptionObject(new InvalidArgumentException(
-            'DateTime has not the instance() method needed to cast the date.'
+            'DateTime has not the instance() method needed to cast the date.',
         ));
 
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $periodClass::create('2010-08-24', CarbonInterval::weeks(2), '2012-07-19')
             ->cast(DateTime::class);
     }
 
     public function testMake()
     {
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $period = $periodClass::make(new DatePeriod(
             new DateTime('2012-07-01'),
             CarbonInterval::days(2),
-            new DateTime('2012-07-07')
+            new DateTime('2012-07-07'),
         ));
 
         $this->assertInstanceOf($periodClass, $period);
@@ -760,22 +789,22 @@ class CreateTest extends AbstractTestCase
     public function testInstanceInvalidType()
     {
         $this->expectExceptionObject(new NotAPeriodException(
-            'Argument 1 passed to Carbon\CarbonPeriod::Carbon\CarbonPeriod::instance() '.
-            'must be an instance of DatePeriod or Carbon\CarbonPeriod, string given.'
+            'Argument 1 passed to '.static::$periodClass.'::instance() '.
+            'must be an instance of DatePeriod or '.static::$periodClass.', string given.',
         ));
 
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $periodClass::instance('hello');
     }
 
     public function testInstanceInvalidInstance()
     {
         $this->expectExceptionObject(new NotAPeriodException(
-            'Argument 1 passed to Carbon\CarbonPeriod::Carbon\CarbonPeriod::instance() '.
-            'must be an instance of DatePeriod or Carbon\CarbonPeriod, instance of Carbon\Carbon given.'
+            'Argument 1 passed to '.static::$periodClass.'::instance() '.
+            'must be an instance of DatePeriod or '.static::$periodClass.', instance of Carbon\Carbon given.',
         ));
 
-        $periodClass = $this->periodClass;
+        $periodClass = static::$periodClass;
         $periodClass::instance(Carbon::now());
     }
 
@@ -784,38 +813,149 @@ class CreateTest extends AbstractTestCase
         $this->assertSame(
             [Carbon::class, Carbon::class, Carbon::class],
             iterator_to_array(
-                CarbonPeriod::between(Carbon::today(), Carbon::today()->addDays(2))->map('get_class')
-            )
+                CarbonPeriod::between(Carbon::today(), Carbon::today()->addDays(2))->map('get_class'),
+            ),
         );
         $this->assertSame(
             [Carbon::class, Carbon::class, Carbon::class],
             iterator_to_array(
-                CarbonPeriod::between(CarbonImmutable::today(), CarbonImmutable::today()->addDays(2))->map('get_class')
-            )
+                CarbonPeriod::between(CarbonImmutable::today(), CarbonImmutable::today()->addDays(2))->map('get_class'),
+            ),
         );
         $this->assertSame(
             [Carbon::class, Carbon::class, Carbon::class],
             iterator_to_array(
-                CarbonPeriod::between('today', 'today + 2 days')->map('get_class')
-            )
+                CarbonPeriod::between('today', 'today + 2 days')->map('get_class'),
+            ),
         );
         $this->assertSame(
             [CarbonImmutable::class, CarbonImmutable::class, CarbonImmutable::class],
             iterator_to_array(
-                CarbonPeriodImmutable::between(Carbon::today(), Carbon::today()->addDays(2))->map('get_class')
-            )
+                CarbonPeriodImmutable::between(Carbon::today(), Carbon::today()->addDays(2))->map(get_class(...)),
+            ),
         );
         $this->assertSame(
             [CarbonImmutable::class, CarbonImmutable::class, CarbonImmutable::class],
             iterator_to_array(
-                CarbonPeriodImmutable::between(CarbonImmutable::today(), CarbonImmutable::today()->addDays(2))->map('get_class')
-            )
+                CarbonPeriodImmutable::between(CarbonImmutable::today(), CarbonImmutable::today()->addDays(2))->map('get_class'),
+            ),
         );
         $this->assertSame(
             [CarbonImmutable::class, CarbonImmutable::class, CarbonImmutable::class],
             iterator_to_array(
-                CarbonPeriodImmutable::between('today', 'today + 2 days')->map('get_class')
-            )
+                CarbonPeriodImmutable::between('today', 'today + 2 days')->map('get_class'),
+            ),
         );
     }
+
+    public function testEnums()
+    {
+        $periodClass = static::$periodClass;
+        $immutable = ($periodClass === CarbonPeriodImmutable::class);
+        /** @var CarbonPeriod $period */
+        $period = $periodClass::create(Month::January, Unit::Month, Month::June);
+
+        $this->assertTrue($period->isStartIncluded());
+        $this->assertTrue($period->isEndIncluded());
+        $carbonClass = $immutable ? CarbonImmutable::class : Carbon::class;
+
+        $this->assertSame(
+            array_fill(0, 6, $carbonClass),
+            iterator_to_array($period->map(get_class(...))),
+        );
+        $this->assertSame(
+            ['01-01', '02-01', '03-01', '04-01', '05-01', '06-01'],
+            iterator_to_array($period->map(static fn (CarbonInterface $date) => $date->format('m-d'))),
+        );
+
+        $result = $period->setDateInterval(Unit::Week);
+
+        if ($immutable) {
+            $this->assertSame(6, $period->count());
+
+            $period = $result;
+        }
+
+        $this->assertSame(22, $period->count());
+
+        $result = $period->setDateInterval(3, Unit::Week);
+
+        if ($immutable) {
+            $this->assertSame(22, $period->count());
+
+            $period = $result;
+        }
+
+        $this->assertSame(8, $period->count());
+
+        $result = $period->setDateInterval(Unit::Quarter);
+
+        if ($immutable) {
+            $this->assertSame(8, $period->count());
+
+            $period = $result;
+        }
+
+        $this->assertSame(2, $period->count());
+    }
+
+    public function testStartAndEndFallback()
+    {
+        Carbon::setTestNow('2024-06-15');
+
+        $this->assertSame([
+            '2024-09-01',
+            '2024-09-30',
+        ], [
+            Carbon::parse('Sep 1')->toPeriod('Sep 30')->start->format('Y-m-d'),
+            Carbon::parse('Sep 1')->toPeriod('Sep 30')->end->format('Y-m-d'),
+        ]);
+
+        $periodClass = static::$periodClass;
+        $period = new $periodClass('Sep 1', 'Sep 30');
+
+        $this->assertSame([
+            '2024-09-01',
+            '2024-09-30',
+        ], [
+            $period->start->format('Y-m-d'),
+            $period->end->format('Y-m-d'),
+        ]);
+
+        $period = new $periodClass('Sep 1');
+
+        $this->assertSame([
+            '2024-09-01',
+            null,
+        ], [
+            $period->start->format('Y-m-d'),
+            $period->end?->format('Y-m-d'),
+        ]);
+    }
+
+    public function testSlashFormat()
+    {
+        $periodClass = static::$periodClass;
+        $period = $periodClass::create('2024-09-01/3 days/2024-09-30');
+
+        $this->assertSame('+3', $period->interval->format('%R%d'));
+        $this->assertSame('3 days', $period->dateInterval->forHumans());
+        $this->assertSame([
+            '2024-09-01',
+            '2024-09-30',
+        ], [
+            $period->start->format('Y-m-d'),
+            $period->end->format('Y-m-d'),
+        ]);
+    }
+
+    public function testInvalidTimezone()
+    {
+        $this->expectExceptionObject(new InvalidPeriodParameterException(
+            'Invalid constructor parameters.',
+        ));
+
+        $periodClass = static::$periodClass;
+        new $periodClass('2024-09-01', '3 days', '2024-09-30', 'America/Tokyo');
+    }
 }
