@@ -1,6 +1,16 @@
 <?php
+
 declare(strict_types=1);
 
+/**
+ * This file is part of the Carbon package.
+ *
+ * (c) Brian Nesbitt <brian@nesbot.com>
+ *
+ * For the full copyright and license information, please view the LICENSE
+ * file that was distributed with this source code.
+ */
+
 namespace Tests\Jenssegers;
 
 use Carbon\Carbon;
@@ -30,7 +40,7 @@ class JenssegersDate extends Carbon
 
     public static function jngParse($time = null, $tz = null)
     {
-        if (is_string($time)) {
+        if (\is_string($time)) {
             $time = static::translateTimeString($time, static::getLocale(), 'en');
         }
 
@@ -39,7 +49,7 @@ class JenssegersDate extends Carbon
 
     public static function jngCreateFromFormat($format, $time = null, $tz = null)
     {
-        if (is_string($time)) {
+        if (\is_string($time)) {
             $time = static::translateTimeString($time, static::getLocale(), 'en');
         }
 
