@@ -22,19 +22,14 @@ class EventDispatcherBase
 
     public function listen($name, $listener)
     {
-        if (!isset($this->listeners[$name])) {
-            $this->listeners[$name] = [];
-        }
-
+        $this->listeners[$name] ??= [];
         $this->listeners[$name][] = $listener;
     }
 
     public function dispatch($name, $event = null)
     {
-        if (isset($this->listeners[$name])) {
-            foreach ($this->listeners[$name] as $listener) {
-                $listener($event);
-            }
+        foreach (($this->listeners[$name] ?? []) as $listener) {
+            $listener($event);
         }
     }
 }
