@@ -13,219 +13,424 @@ declare(strict_types=1);
 
 namespace Tests\Localization;
 
-/**
- * @group localization
- */
+use PHPUnit\Framework\Attributes\Group;
+
+#[Group('localization')]
 class BemZmTest extends LocalizationTestCase
 {
     public const LOCALE = 'bem_ZM'; // Bemba
 
     public const CASES = [
         // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Tomorrow at 12:00 AM'
         'Tomorrow at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Saturday at 12:00 AM'
         'Pachibelushi at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Sunday at 12:00 AM'
         'Pa Mulungu at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Monday at 12:00 AM'
         'Palichimo at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Tuesday at 12:00 AM'
         'Palichibuli at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Wednesday at 12:00 AM'
         'Palichitatu at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
+        // 'Thursday at 12:00 AM'
         'Palichine at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
+        // 'Friday at 12:00 AM'
         'Palichisano at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Tuesday at 12:00 AM'
         'Palichibuli at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Wednesday at 12:00 AM'
         'Palichitatu at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Thursday at 12:00 AM'
         'Palichine at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Friday at 12:00 AM'
         'Palichisano at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Saturday at 12:00 AM'
         'Pachibelushi at 12:00 uluchelo',
+
         // Carbon::now()->subDays(2)->calendar()
+        // 'Last Sunday at 8:49 PM'
         'Last Pa Mulungu at 8:49 akasuba',
+
         // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Yesterday at 10:00 PM'
         'Yesterday at 10:00 akasuba',
+
         // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
+        // 'Today at 10:00 AM'
         'Today at 10:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Today at 2:00 AM'
         'Today at 2:00 uluchelo',
+
         // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
+        // 'Tomorrow at 1:00 AM'
         'Tomorrow at 1:00 uluchelo',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Tuesday at 12:00 AM'
         'Palichibuli at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
+        // 'Yesterday at 12:00 AM'
         'Yesterday at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Yesterday at 12:00 AM'
         'Yesterday at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Tuesday at 12:00 AM'
         'Last Palichibuli at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Monday at 12:00 AM'
         'Last Palichimo at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Sunday at 12:00 AM'
         'Last Pa Mulungu at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Saturday at 12:00 AM'
         'Last Pachibelushi at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Friday at 12:00 AM'
         'Last Palichisano at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
+        // 'Last Thursday at 12:00 AM'
         'Last Palichine at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
+        // 'Last Wednesday at 12:00 AM'
         'Last Palichitatu at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Last Friday at 12:00 AM'
         'Last Palichisano at 12:00 uluchelo',
+
         // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
+        // '1st 1st 1st 1st 1st'
         '1st 1st 1st 1st 1st',
+
         // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
+        // '2nd 1st'
         '2nd 1st',
+
         // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
+        // '3rd 1st'
         '3rd 1st',
+
         // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
+        // '4th 1st'
         '4th 1st',
+
         // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
+        // '5th 1st'
         '5th 1st',
+
         // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
+        // '6th 1st'
         '6th 1st',
+
         // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
+        // '7th 1st'
         '7th 1st',
+
         // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
+        // '11th 2nd'
         '11th 2nd',
+
         // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
+        // '40th'
         '40th',
+
         // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
+        // '41st'
         '41st',
+
         // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
+        // '100th'
         '100th',
+
         // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
+        // '12:00 am CET'
         '12:00 uluchelo CET',
+
         // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
+        // '12:00 AM, 12:00 am'
         '12:00 uluchelo, 12:00 uluchelo',
+
         // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
+        // '1:30 AM, 1:30 am'
         '1:30 uluchelo, 1:30 uluchelo',
+
         // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
+        // '2:00 AM, 2:00 am'
         '2:00 uluchelo, 2:00 uluchelo',
+
         // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
+        // '6:00 AM, 6:00 am'
         '6:00 uluchelo, 6:00 uluchelo',
+
         // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
+        // '10:00 AM, 10:00 am'
         '10:00 uluchelo, 10:00 uluchelo',
+
         // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
+        // '12:00 PM, 12:00 pm'
         '12:00 akasuba, 12:00 akasuba',
+
         // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
+        // '5:00 PM, 5:00 pm'
         '5:00 akasuba, 5:00 akasuba',
+
         // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
+        // '9:30 PM, 9:30 pm'
         '9:30 akasuba, 9:30 akasuba',
+
         // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
+        // '11:00 PM, 11:00 pm'
         '11:00 akasuba, 11:00 akasuba',
+
         // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
+        // '0th'
         '0th',
+
         // Carbon::now()->subSeconds(1)->diffForHumans()
+        // '1 second ago'
         'sekondi 1 ago',
+
         // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
+        // '1s ago'
         'sekondi 1 ago',
+
         // Carbon::now()->subSeconds(2)->diffForHumans()
+        // '2 seconds ago'
         'sekondi 2 ago',
+
         // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
+        // '2s ago'
         'sekondi 2 ago',
+
         // Carbon::now()->subMinutes(1)->diffForHumans()
+        // '1 minute ago'
         'miniti 1 ago',
+
         // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
+        // '1m ago'
         'miniti 1 ago',
+
         // Carbon::now()->subMinutes(2)->diffForHumans()
+        // '2 minutes ago'
         'miniti 2 ago',
+
         // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
+        // '2m ago'
         'miniti 2 ago',
+
         // Carbon::now()->subHours(1)->diffForHumans()
+        // '1 hour ago'
         'awala 1 ago',
+
         // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
+        // '1h ago'
         'awala 1 ago',
+
         // Carbon::now()->subHours(2)->diffForHumans()
+        // '2 hours ago'
         'awala 2 ago',
+
         // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
+        // '2h ago'
         'awala 2 ago',
+
         // Carbon::now()->subDays(1)->diffForHumans()
+        // '1 day ago'
         'inshiku 1 ago',
+
         // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
+        // '1d ago'
         'inshiku 1 ago',
+
         // Carbon::now()->subDays(2)->diffForHumans()
+        // '2 days ago'
         'inshiku 2 ago',
+
         // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
+        // '2d ago'
         'inshiku 2 ago',
+
         // Carbon::now()->subWeeks(1)->diffForHumans()
+        // '1 week ago'
         'umulungu 1 ago',
+
         // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
+        // '1w ago'
         'umulungu 1 ago',
+
         // Carbon::now()->subWeeks(2)->diffForHumans()
+        // '2 weeks ago'
         'umulungu 2 ago',
+
         // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
+        // '2w ago'
         'umulungu 2 ago',
+
         // Carbon::now()->subMonths(1)->diffForHumans()
+        // '1 month ago'
         'myeshi 1 ago',
+
         // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
+        // '1mo ago'
         'myeshi 1 ago',
+
         // Carbon::now()->subMonths(2)->diffForHumans()
+        // '2 months ago'
         'myeshi 2 ago',
+
         // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
+        // '2mos ago'
         'myeshi 2 ago',
+
         // Carbon::now()->subYears(1)->diffForHumans()
+        // '1 year ago'
         'myaka 1 ago',
+
         // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
+        // '1yr ago'
         'myaka 1 ago',
+
         // Carbon::now()->subYears(2)->diffForHumans()
+        // '2 years ago'
         'myaka 2 ago',
+
         // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
+        // '2yrs ago'
         'myaka 2 ago',
+
         // Carbon::now()->addSecond()->diffForHumans()
+        // '1 second from now'
         'sekondi 1 from now',
+
         // Carbon::now()->addSecond()->diffForHumans(null, false, true)
+        // '1s from now'
         'sekondi 1 from now',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
+        // '1 second after'
         'sekondi 1 after',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
+        // '1s after'
         'sekondi 1 after',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
+        // '1 second before'
         'sekondi 1 before',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
+        // '1s before'
         'sekondi 1 before',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
+        // '1 second'
         'sekondi 1',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
+        // '1s'
         'sekondi 1',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
+        // '2 seconds'
         'sekondi 2',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
+        // '2s'
         'sekondi 2',
+
         // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
+        // '1s from now'
         'sekondi 1 from now',
+
         // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
+        // '1 minute 1 second'
         'miniti 1 sekondi 1',
+
         // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
+        // '2yrs 3mos 1d 1s'
         'myaka 2 myeshi 3 inshiku 1 sekondi 1',
+
         // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
+        // '3 years from now'
         'myaka 3 from now',
+
         // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
+        // '5mos ago'
         'myeshi 5 ago',
+
         // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
+        // '2yrs 3mos 1d 1s ago'
         'myaka 2 myeshi 3 inshiku 1 sekondi 1 ago',
+
         // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
+        // '1 week 10 hours'
         'umulungu 1 awala 10',
+
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
+        // '1 week 6 days'
         'umulungu 1 inshiku 6',
+
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
+        // '1 week 6 days'
         'umulungu 1 inshiku 6',
+
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
+        // '1 week and 6 days from now'
         'umulungu 1 and inshiku 6 from now',
+
         // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
+        // '2 weeks 1 hour'
         'umulungu 2 awala 1',
+
         // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
+        // 'an hour from now'
         'awala 1 from now',
+
         // CarbonInterval::days(2)->forHumans()
+        // '2 days'
         'inshiku 2',
+
         // CarbonInterval::create('P1DT3H')->forHumans(true)
+        // '1d 3h'
         'inshiku 1 awala 3',
     ];
 }
