@@ -13,9 +13,9 @@ declare(strict_types=1);
 
 namespace Tests\Localization;
 
-/**
- * @group localization
- */
+use PHPUnit\Framework\Attributes\Group;
+
+#[Group('localization')]
 class BsCyrlTest extends LocalizationTestCase
 {
     public const LOCALE = 'bs_Cyrl'; // Bosnian
@@ -156,13 +156,13 @@ class BsCyrlTest extends LocalizationTestCase
         // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
         'prije 2 dana',
         // Carbon::now()->subWeeks(1)->diffForHumans()
-        'prije 1 sedmice',
+        'prije 1 sedmicu',
         // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
-        'prije 1 sedmice',
+        'prije 1 sedmica',
         // Carbon::now()->subWeeks(2)->diffForHumans()
-        'prije 2 sedmicu',
+        'prije 2 sedmice',
         // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
-        'prije 2 sedmicu',
+        'prije 2 sedmice',
         // Carbon::now()->subMonths(1)->diffForHumans()
         'prije 1 mjesec',
         // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
@@ -172,7 +172,7 @@ class BsCyrlTest extends LocalizationTestCase
         // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
         'prije 2 mjeseca',
         // Carbon::now()->subYears(1)->diffForHumans()
-        'prije 1 godina',
+        'prije 1 godinu',
         // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
         'prije 1 godina',
         // Carbon::now()->subYears(2)->diffForHumans()
@@ -212,15 +212,15 @@ class BsCyrlTest extends LocalizationTestCase
         // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
         'prije 2 godine 3 mjeseca 1 dan 1 sekund',
         // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
-        '1 sedmice 10 sati',
+        '1 sedmica 10 sati',
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
-        '1 sedmice 6 dana',
+        '1 sedmica 6 dana',
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
-        '1 sedmice 6 dana',
+        '1 sedmica 6 dana',
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
-        'za 1 sedmice i 6 dana',
+        'za 1 sedmicu i 6 dana',
         // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
-        '2 sedmicu 1 sat',
+        '2 sedmice 1 sat',
         // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
         'za 1 sat',
         // CarbonInterval::days(2)->forHumans()
