@@ -13,219 +13,424 @@ declare(strict_types=1);
 
 namespace Tests\Localization;
 
-/**
- * @group localization
- */
+use PHPUnit\Framework\Attributes\Group;
+
+#[Group('localization')]
 class PaArabTest extends LocalizationTestCase
 {
     public const LOCALE = 'pa_Arab'; // Panjabi
 
     public const CASES = [
         // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Tomorrow at 12:00 AM'
         'کل بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Saturday at 12:00 AM'
         'ہفتہ بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Sunday at 12:00 AM'
         'اتوار بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Monday at 12:00 AM'
         'پیر بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Tuesday at 12:00 AM'
         'منگل بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Wednesday at 12:00 AM'
         'بُدھ بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
+        // 'Thursday at 12:00 AM'
         'جمعرات بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
+        // 'Friday at 12:00 AM'
         'جمعہ بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Tuesday at 12:00 AM'
         'منگل بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Wednesday at 12:00 AM'
         'بُدھ بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Thursday at 12:00 AM'
         'جمعرات بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Friday at 12:00 AM'
         'جمعہ بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Saturday at 12:00 AM'
         'ہفتہ بوقت 12:00 صبح',
+
         // Carbon::now()->subDays(2)->calendar()
+        // 'Last Sunday at 8:49 PM'
         'گذشتہ اتوار بوقت 8:49 شام',
+
         // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Yesterday at 10:00 PM'
         'گذشتہ روز بوقت 10:00 شام',
+
         // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
+        // 'Today at 10:00 AM'
         'آج بوقت 10:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Today at 2:00 AM'
         'آج بوقت 2:00 صبح',
+
         // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
+        // 'Tomorrow at 1:00 AM'
         'کل بوقت 1:00 صبح',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Tuesday at 12:00 AM'
         'منگل بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
+        // 'Yesterday at 12:00 AM'
         'گذشتہ روز بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Yesterday at 12:00 AM'
         'گذشتہ روز بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Tuesday at 12:00 AM'
         'گذشتہ منگل بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Monday at 12:00 AM'
         'گذشتہ پیر بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Sunday at 12:00 AM'
         'گذشتہ اتوار بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Saturday at 12:00 AM'
         'گذشتہ ہفتہ بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Friday at 12:00 AM'
         'گذشتہ جمعہ بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
+        // 'Last Thursday at 12:00 AM'
         'گذشتہ جمعرات بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
+        // 'Last Wednesday at 12:00 AM'
         'گذشتہ بُدھ بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Last Friday at 12:00 AM'
         'گذشتہ جمعہ بوقت 12:00 صبح',
+
         // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
+        // '1st 1st 1st 1st 1st'
         '1 1 1 1 1',
+
         // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
+        // '2nd 1st'
         '2 1',
+
         // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
+        // '3rd 1st'
         '3 1',
+
         // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
+        // '4th 1st'
         '4 1',
+
         // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
+        // '5th 1st'
         '5 1',
+
         // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
+        // '6th 1st'
         '6 1',
+
         // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
+        // '7th 1st'
         '7 1',
+
         // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
+        // '11th 2nd'
         '11 2',
+
         // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
+        // '40th'
         '40',
+
         // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
+        // '41st'
         '41',
+
         // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
+        // '100th'
         '100',
+
         // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
+        // '12:00 am CET'
         '12:00 صبح CET',
+
         // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
+        // '12:00 AM, 12:00 am'
         '12:00 صبح, 12:00 صبح',
+
         // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
+        // '1:30 AM, 1:30 am'
         '1:30 صبح, 1:30 صبح',
+
         // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
+        // '2:00 AM, 2:00 am'
         '2:00 صبح, 2:00 صبح',
+
         // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
+        // '6:00 AM, 6:00 am'
         '6:00 صبح, 6:00 صبح',
+
         // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
+        // '10:00 AM, 10:00 am'
         '10:00 صبح, 10:00 صبح',
+
         // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
+        // '12:00 PM, 12:00 pm'
         '12:00 شام, 12:00 شام',
+
         // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
+        // '5:00 PM, 5:00 pm'
         '5:00 شام, 5:00 شام',
+
         // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
+        // '9:30 PM, 9:30 pm'
         '9:30 شام, 9:30 شام',
+
         // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
+        // '11:00 PM, 11:00 pm'
         '11:00 شام, 11:00 شام',
+
         // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
+        // '0th'
         '0',
+
         // Carbon::now()->subSeconds(1)->diffForHumans()
-        'چند سیکنڈ قبل',
+        // '1 second ago'
+        '1 سیکنڈ قبل',
+
         // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
-        'چند سیکنڈ قبل',
+        // '1s ago'
+        '1 سیکنڈ قبل',
+
         // Carbon::now()->subSeconds(2)->diffForHumans()
+        // '2 seconds ago'
         '2 سیکنڈ قبل',
+
         // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
+        // '2s ago'
         '2 سیکنڈ قبل',
+
         // Carbon::now()->subMinutes(1)->diffForHumans()
-        'ایک منٹ قبل',
+        // '1 minute ago'
+        '1 منٹ قبل',
+
         // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
-        'ایک منٹ قبل',
+        // '1m ago'
+        '1 منٹ قبل',
+
         // Carbon::now()->subMinutes(2)->diffForHumans()
+        // '2 minutes ago'
         '2 منٹ قبل',
+
         // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
+        // '2m ago'
         '2 منٹ قبل',
+
         // Carbon::now()->subHours(1)->diffForHumans()
-        'ایک گھنٹہ قبل',
+        // '1 hour ago'
+        '1 گھنٹے قبل',
+
         // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
-        'ایک گھنٹہ قبل',
+        // '1h ago'
+        '1 گھنٹے قبل',
+
         // Carbon::now()->subHours(2)->diffForHumans()
+        // '2 hours ago'
         '2 گھنٹے قبل',
+
         // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
+        // '2h ago'
         '2 گھنٹے قبل',
+
         // Carbon::now()->subDays(1)->diffForHumans()
-        'ایک دن قبل',
+        // '1 day ago'
+        '1 دن قبل',
+
         // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
-        'ایک دن قبل',
+        // '1d ago'
+        '1 دن قبل',
+
         // Carbon::now()->subDays(2)->diffForHumans()
+        // '2 days ago'
         '2 دن قبل',
+
         // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
+        // '2d ago'
         '2 دن قبل',
+
         // Carbon::now()->subWeeks(1)->diffForHumans()
+        // '1 week ago'
         '1 ہفتے قبل',
+
         // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
+        // '1w ago'
         '1 ہفتے قبل',
+
         // Carbon::now()->subWeeks(2)->diffForHumans()
+        // '2 weeks ago'
         '2 ہفتے قبل',
+
         // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
+        // '2w ago'
         '2 ہفتے قبل',
+
         // Carbon::now()->subMonths(1)->diffForHumans()
-        'ایک ماہ قبل',
+        // '1 month ago'
+        '1 ماہ قبل',
+
         // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
-        'ایک ماہ قبل',
+        // '1mo ago'
+        '1 ماہ قبل',
+
         // Carbon::now()->subMonths(2)->diffForHumans()
+        // '2 months ago'
         '2 ماہ قبل',
+
         // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
+        // '2mos ago'
         '2 ماہ قبل',
+
         // Carbon::now()->subYears(1)->diffForHumans()
-        'ایک سال قبل',
+        // '1 year ago'
+        '1 سال قبل',
+
         // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
-        'ایک سال قبل',
+        // '1yr ago'
+        '1 سال قبل',
+
         // Carbon::now()->subYears(2)->diffForHumans()
+        // '2 years ago'
         '2 سال قبل',
+
         // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
+        // '2yrs ago'
         '2 سال قبل',
+
         // Carbon::now()->addSecond()->diffForHumans()
-        'چند سیکنڈ بعد',
+        // '1 second from now'
+        '1 سیکنڈ بعد',
+
         // Carbon::now()->addSecond()->diffForHumans(null, false, true)
-        'چند سیکنڈ بعد',
+        // '1s from now'
+        '1 سیکنڈ بعد',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
-        'چند سیکنڈ بعد',
+        // '1 second after'
+        '1 سیکنڈ بعد',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
-        'چند سیکنڈ بعد',
+        // '1s after'
+        '1 سیکنڈ بعد',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
-        'چند سیکنڈ پہلے',
+        // '1 second before'
+        '1 سیکنڈ پہلے',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
-        'چند سیکنڈ پہلے',
+        // '1s before'
+        '1 سیکنڈ پہلے',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
-        'چند سیکنڈ',
+        // '1 second'
+        '1 سیکنڈ',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
-        'چند سیکنڈ',
+        // '1s'
+        '1 سیکنڈ',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
+        // '2 seconds'
         '2 سیکنڈ',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
+        // '2s'
         '2 سیکنڈ',
+
         // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
-        'چند سیکنڈ بعد',
+        // '1s from now'
+        '1 سیکنڈ بعد',
+
         // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
-        'ایک منٹ چند سیکنڈ',
+        // '1 minute 1 second'
+        '1 منٹ 1 سیکنڈ',
+
         // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
-        '2 سال 3 ماہ ایک دن چند سیکنڈ',
+        // '2yrs 3mos 1d 1s'
+        '2 سال 3 ماہ 1 دن 1 سیکنڈ',
+
         // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
+        // '3 years from now'
         '3 سال بعد',
+
         // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
+        // '5mos ago'
         '5 ماہ قبل',
+
         // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
-        '2 سال 3 ماہ ایک دن چند سیکنڈ قبل',
+        // '2yrs 3mos 1d 1s ago'
+        '2 سال 3 ماہ 1 دن 1 سیکنڈ قبل',
+
         // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
+        // '1 week 10 hours'
         '1 ہفتے 10 گھنٹے',
+
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
+        // '1 week 6 days'
         '1 ہفتے 6 دن',
+
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
+        // '1 week 6 days'
         '1 ہفتے 6 دن',
+
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
+        // '1 week and 6 days from now'
         '1 ہفتے اور 6 دن بعد',
+
         // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
-        '2 ہفتے ایک گھنٹہ',
+        // '2 weeks 1 hour'
+        '2 ہفتے 1 گھنٹے',
+
         // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
+        // 'an hour from now'
         'ایک گھنٹہ بعد',
+
         // CarbonInterval::days(2)->forHumans()
+        // '2 days'
         '2 دن',
+
         // CarbonInterval::create('P1DT3H')->forHumans(true)
-        'ایک دن 3 گھنٹے',
+        // '1d 3h'
+        '1 دن 3 گھنٹے',
     ];
 }
