@@ -13,219 +13,424 @@ declare(strict_types=1);
 
 namespace Tests\Localization;
 
-/**
- * @group localization
- */
+use PHPUnit\Framework\Attributes\Group;
+
+#[Group('localization')]
 class SoDjTest extends LocalizationTestCase
 {
     public const LOCALE = 'so_DJ'; // Somali
 
     public const CASES = [
         // Carbon::parse('2018-01-04 00:00:00')->addDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Tomorrow at 12:00 AM'
         'Beri markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Saturday at 12:00 AM'
         'Sabti markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Sunday at 12:00 AM'
         'Axad markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Monday at 12:00 AM'
         'Isniin markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Tuesday at 12:00 AM'
         'Talaada markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Wednesday at 12:00 AM'
         'Arbaca markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-05 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-05 00:00:00'))
+        // 'Thursday at 12:00 AM'
         'Khamiis markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-06 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-06 00:00:00'))
+        // 'Friday at 12:00 AM'
         'Jimce markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Tuesday at 12:00 AM'
         'Talaada markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(3)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Wednesday at 12:00 AM'
         'Arbaca markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(4)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Thursday at 12:00 AM'
         'Khamiis markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(5)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Friday at 12:00 AM'
         'Jimce markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(6)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Saturday at 12:00 AM'
         'Sabti markay tahay 12:00 AM',
+
         // Carbon::now()->subDays(2)->calendar()
+        // 'Last Sunday at 8:49 PM'
         'Hore Axad Markay ahayd 8:49 PM',
+
         // Carbon::parse('2018-01-04 00:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Yesterday at 10:00 PM'
         'Shalay markay ahayd 10:00 PM',
+
         // Carbon::parse('2018-01-04 12:00:00')->subHours(2)->calendar(Carbon::parse('2018-01-04 12:00:00'))
+        // 'Today at 10:00 AM'
         'Maanta markay tahay 10:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Today at 2:00 AM'
         'Maanta markay tahay 2:00 AM',
+
         // Carbon::parse('2018-01-04 23:00:00')->addHours(2)->calendar(Carbon::parse('2018-01-04 23:00:00'))
+        // 'Tomorrow at 1:00 AM'
         'Beri markay tahay 1:00 AM',
+
         // Carbon::parse('2018-01-07 00:00:00')->addDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Tuesday at 12:00 AM'
         'Talaada markay tahay 12:00 AM',
+
         // Carbon::parse('2018-01-08 00:00:00')->subDay()->calendar(Carbon::parse('2018-01-08 00:00:00'))
+        // 'Yesterday at 12:00 AM'
         'Shalay markay ahayd 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(1)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Yesterday at 12:00 AM'
         'Shalay markay ahayd 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Tuesday at 12:00 AM'
         'Hore Talaada Markay ahayd 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(3)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Monday at 12:00 AM'
         'Hore Isniin Markay ahayd 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(4)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Sunday at 12:00 AM'
         'Hore Axad Markay ahayd 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(5)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Saturday at 12:00 AM'
         'Hore Sabti Markay ahayd 12:00 AM',
+
         // Carbon::parse('2018-01-04 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-04 00:00:00'))
+        // 'Last Friday at 12:00 AM'
         'Hore Jimce Markay ahayd 12:00 AM',
+
         // Carbon::parse('2018-01-03 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-03 00:00:00'))
+        // 'Last Thursday at 12:00 AM'
         'Hore Khamiis Markay ahayd 12:00 AM',
+
         // Carbon::parse('2018-01-02 00:00:00')->subDays(6)->calendar(Carbon::parse('2018-01-02 00:00:00'))
+        // 'Last Wednesday at 12:00 AM'
         'Hore Arbaca Markay ahayd 12:00 AM',
+
         // Carbon::parse('2018-01-07 00:00:00')->subDays(2)->calendar(Carbon::parse('2018-01-07 00:00:00'))
+        // 'Last Friday at 12:00 AM'
         'Hore Jimce Markay ahayd 12:00 AM',
+
         // Carbon::parse('2018-01-01 00:00:00')->isoFormat('Qo Mo Do Wo wo')
-        '1 1 1 1 1',
+        // '1st 1st 1st 1st 1st'
+        '1st 1st 1st 1st 1st',
+
         // Carbon::parse('2018-01-02 00:00:00')->isoFormat('Do wo')
-        '2 1',
+        // '2nd 1st'
+        '2nd 1st',
+
         // Carbon::parse('2018-01-03 00:00:00')->isoFormat('Do wo')
-        '3 1',
+        // '3rd 1st'
+        '3rd 1st',
+
         // Carbon::parse('2018-01-04 00:00:00')->isoFormat('Do wo')
-        '4 1',
+        // '4th 1st'
+        '4th 1st',
+
         // Carbon::parse('2018-01-05 00:00:00')->isoFormat('Do wo')
-        '5 1',
+        // '5th 1st'
+        '5th 1st',
+
         // Carbon::parse('2018-01-06 00:00:00')->isoFormat('Do wo')
-        '6 2',
+        // '6th 1st'
+        '6th 2nd',
+
         // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
-        '7 2',
+        // '7th 1st'
+        '7th 2nd',
+
         // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
-        '11 2',
+        // '11th 2nd'
+        '11th 2nd',
+
         // Carbon::parse('2018-02-09 00:00:00')->isoFormat('DDDo')
-        '40',
+        // '40th'
+        '40th',
+
         // Carbon::parse('2018-02-10 00:00:00')->isoFormat('DDDo')
-        '41',
+        // '41st'
+        '41st',
+
         // Carbon::parse('2018-04-10 00:00:00')->isoFormat('DDDo')
-        '100',
+        // '100th'
+        '100th',
+
         // Carbon::parse('2018-02-10 00:00:00', 'Europe/Paris')->isoFormat('h:mm a z')
+        // '12:00 am CET'
         '12:00 am CET',
+
         // Carbon::parse('2018-02-10 00:00:00')->isoFormat('h:mm A, h:mm a')
+        // '12:00 AM, 12:00 am'
         '12:00 AM, 12:00 am',
+
         // Carbon::parse('2018-02-10 01:30:00')->isoFormat('h:mm A, h:mm a')
+        // '1:30 AM, 1:30 am'
         '1:30 AM, 1:30 am',
+
         // Carbon::parse('2018-02-10 02:00:00')->isoFormat('h:mm A, h:mm a')
+        // '2:00 AM, 2:00 am'
         '2:00 AM, 2:00 am',
+
         // Carbon::parse('2018-02-10 06:00:00')->isoFormat('h:mm A, h:mm a')
+        // '6:00 AM, 6:00 am'
         '6:00 AM, 6:00 am',
+
         // Carbon::parse('2018-02-10 10:00:00')->isoFormat('h:mm A, h:mm a')
+        // '10:00 AM, 10:00 am'
         '10:00 AM, 10:00 am',
+
         // Carbon::parse('2018-02-10 12:00:00')->isoFormat('h:mm A, h:mm a')
+        // '12:00 PM, 12:00 pm'
         '12:00 PM, 12:00 pm',
+
         // Carbon::parse('2018-02-10 17:00:00')->isoFormat('h:mm A, h:mm a')
+        // '5:00 PM, 5:00 pm'
         '5:00 PM, 5:00 pm',
+
         // Carbon::parse('2018-02-10 21:30:00')->isoFormat('h:mm A, h:mm a')
+        // '9:30 PM, 9:30 pm'
         '9:30 PM, 9:30 pm',
+
         // Carbon::parse('2018-02-10 23:00:00')->isoFormat('h:mm A, h:mm a')
+        // '11:00 PM, 11:00 pm'
         '11:00 PM, 11:00 pm',
+
         // Carbon::parse('2018-01-01 00:00:00')->ordinal('hour')
-        '0',
+        // '0th'
+        '0th',
+
         // Carbon::now()->subSeconds(1)->diffForHumans()
+        // '1 second ago'
         '1 ilbidhiqsi kahor',
+
         // Carbon::now()->subSeconds(1)->diffForHumans(null, false, true)
+        // '1s ago'
         '1il kahor',
+
         // Carbon::now()->subSeconds(2)->diffForHumans()
+        // '2 seconds ago'
         '2 ilbidhiqsi kahor',
+
         // Carbon::now()->subSeconds(2)->diffForHumans(null, false, true)
+        // '2s ago'
         '2il kahor',
+
         // Carbon::now()->subMinutes(1)->diffForHumans()
+        // '1 minute ago'
         '1 daqiiqo kahor',
+
         // Carbon::now()->subMinutes(1)->diffForHumans(null, false, true)
+        // '1m ago'
         '1dq kahor',
+
         // Carbon::now()->subMinutes(2)->diffForHumans()
+        // '2 minutes ago'
         '2 daqiiqo kahor',
+
         // Carbon::now()->subMinutes(2)->diffForHumans(null, false, true)
+        // '2m ago'
         '2dq kahor',
+
         // Carbon::now()->subHours(1)->diffForHumans()
+        // '1 hour ago'
         '1 saac kahor',
+
         // Carbon::now()->subHours(1)->diffForHumans(null, false, true)
+        // '1h ago'
         '1sc kahor',
+
         // Carbon::now()->subHours(2)->diffForHumans()
+        // '2 hours ago'
         '2 saac kahor',
+
         // Carbon::now()->subHours(2)->diffForHumans(null, false, true)
+        // '2h ago'
         '2sc kahor',
+
         // Carbon::now()->subDays(1)->diffForHumans()
+        // '1 day ago'
         '1 maalin kahor',
+
         // Carbon::now()->subDays(1)->diffForHumans(null, false, true)
+        // '1d ago'
         '1ml kahor',
+
         // Carbon::now()->subDays(2)->diffForHumans()
+        // '2 days ago'
         '2 maalmood kahor',
+
         // Carbon::now()->subDays(2)->diffForHumans(null, false, true)
+        // '2d ago'
         '2ml kahor',
+
         // Carbon::now()->subWeeks(1)->diffForHumans()
+        // '1 week ago'
         '1 isbuuc kahor',
+
         // Carbon::now()->subWeeks(1)->diffForHumans(null, false, true)
+        // '1w ago'
         '1is kahor',
+
         // Carbon::now()->subWeeks(2)->diffForHumans()
+        // '2 weeks ago'
         '2 isbuuc kahor',
+
         // Carbon::now()->subWeeks(2)->diffForHumans(null, false, true)
+        // '2w ago'
         '2is kahor',
+
         // Carbon::now()->subMonths(1)->diffForHumans()
+        // '1 month ago'
         '1 bil kahor',
+
         // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
+        // '1mo ago'
         '1bil kahor',
+
         // Carbon::now()->subMonths(2)->diffForHumans()
+        // '2 months ago'
         '2 bilood kahor',
+
         // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
+        // '2mos ago'
         '2bil kahor',
+
         // Carbon::now()->subYears(1)->diffForHumans()
+        // '1 year ago'
         '1 sanad kahor',
+
         // Carbon::now()->subYears(1)->diffForHumans(null, false, true)
+        // '1yr ago'
         '1sn kahor',
+
         // Carbon::now()->subYears(2)->diffForHumans()
+        // '2 years ago'
         '2 sanadood kahor',
+
         // Carbon::now()->subYears(2)->diffForHumans(null, false, true)
+        // '2yrs ago'
         '2sn kahor',
+
         // Carbon::now()->addSecond()->diffForHumans()
+        // '1 second from now'
         '1 ilbidhiqsi gudahood',
+
         // Carbon::now()->addSecond()->diffForHumans(null, false, true)
+        // '1s from now'
         '1il gudahood',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now())
+        // '1 second after'
         '1 ilbidhiqsi kedib',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), false, true)
+        // '1s after'
         '1il kedib',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond())
+        // '1 second before'
         '1 ilbidhiqsi kahor',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond(), false, true)
+        // '1s before'
         '1il kahor',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true)
+        // '1 second'
         '1 ilbidhiqsi',
+
         // Carbon::now()->addSecond()->diffForHumans(Carbon::now(), true, true)
+        // '1s'
         '1il',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true)
+        // '2 seconds'
         '2 ilbidhiqsi',
+
         // Carbon::now()->diffForHumans(Carbon::now()->addSecond()->addSecond(), true, true)
+        // '2s'
         '2il',
+
         // Carbon::now()->addSecond()->diffForHumans(null, false, true, 1)
+        // '1s from now'
         '1il gudahood',
+
         // Carbon::now()->addMinute()->addSecond()->diffForHumans(null, true, false, 2)
+        // '1 minute 1 second'
         '1 daqiiqo 1 ilbidhiqsi',
+
         // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
+        // '2yrs 3mos 1d 1s'
         '2sn 3bil 1ml 1il',
+
         // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
+        // '3 years from now'
         '3 sanadood gudahood',
+
         // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
+        // '5mos ago'
         '5bil kahor',
+
         // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
+        // '2yrs 3mos 1d 1s ago'
         '2sn 3bil 1ml 1il kahor',
+
         // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
+        // '1 week 10 hours'
         '1 isbuuc 10 saac',
+
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
+        // '1 week 6 days'
         '1 isbuuc 6 maalmood',
+
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(null, true, false, 2)
+        // '1 week 6 days'
         '1 isbuuc 6 maalmood',
+
         // Carbon::now()->addWeek()->addDays(6)->diffForHumans(["join" => true, "parts" => 2])
+        // '1 week and 6 days from now'
         '1 isbuuc and 6 maalmood gudahood',
+
         // Carbon::now()->addWeeks(2)->addHour()->diffForHumans(null, true, false, 2)
+        // '2 weeks 1 hour'
         '2 isbuuc 1 saac',
+
         // Carbon::now()->addHour()->diffForHumans(["aUnit" => true])
+        // 'an hour from now'
         'saacad gudahood',
+
         // CarbonInterval::days(2)->forHumans()
+        // '2 days'
         '2 maalmood',
+
         // CarbonInterval::create('P1DT3H')->forHumans(true)
+        // '1d 3h'
         '1ml 3sc',
     ];
 }
