@@ -13,9 +13,9 @@ declare(strict_types=1);
 
 namespace Tests\Localization;
 
-/**
- * @group localization
- */
+use PHPUnit\Framework\Attributes\Group;
+
+#[Group('localization')]
 class SrRsLatinTest extends LocalizationTestCase
 {
     public const LOCALE = 'sr_RS@latin'; // Serbian
@@ -162,7 +162,7 @@ class SrRsLatinTest extends LocalizationTestCase
         '6. 1.',
 
         // Carbon::parse('2018-01-07 00:00:00')->isoFormat('Do wo')
-        // '7th 2nd'
+        // '7th 1st'
         '7. 1.',
 
         // Carbon::parse('2018-01-11 00:00:00')->isoFormat('Do wo')
@@ -311,7 +311,7 @@ class SrRsLatinTest extends LocalizationTestCase
 
         // Carbon::now()->subMonths(1)->diffForHumans(null, false, true)
         // '1mo ago'
-        'pre 1 mj.',
+        'pre 1 mes.',
 
         // Carbon::now()->subMonths(2)->diffForHumans()
         // '2 months ago'
@@ -319,7 +319,7 @@ class SrRsLatinTest extends LocalizationTestCase
 
         // Carbon::now()->subMonths(2)->diffForHumans(null, false, true)
         // '2mos ago'
-        'pre 2 mj.',
+        'pre 2 mes.',
 
         // Carbon::now()->subYears(1)->diffForHumans()
         // '1 year ago'
@@ -387,7 +387,7 @@ class SrRsLatinTest extends LocalizationTestCase
 
         // Carbon::now()->addYears(2)->addMonths(3)->addDay()->addSecond()->diffForHumans(null, true, true, 4)
         // '2yrs 3mos 1d 1s'
-        '2 g. 3 mj. 1 d. 1 sek.',
+        '2 g. 3 mes. 1 d. 1 sek.',
 
         // Carbon::now()->addYears(3)->diffForHumans(null, null, false, 4)
         // '3 years from now'
@@ -395,11 +395,11 @@ class SrRsLatinTest extends LocalizationTestCase
 
         // Carbon::now()->subMonths(5)->diffForHumans(null, null, true, 4)
         // '5mos ago'
-        'pre 5 mj.',
+        'pre 5 mes.',
 
         // Carbon::now()->subYears(2)->subMonths(3)->subDay()->subSecond()->diffForHumans(null, null, true, 4)
         // '2yrs 3mos 1d 1s ago'
-        'pre 2 g. 3 mj. 1 d. 1 sek.',
+        'pre 2 g. 3 mes. 1 d. 1 sek.',
 
         // Carbon::now()->addWeek()->addHours(10)->diffForHumans(null, true, false, 2)
         // '1 week 10 hours'
