@@ -13,15 +13,17 @@ declare(strict_types=1);
 
 namespace Tests\PHPStan;
 
+use PHPUnit\Framework\Attributes\Large;
 use RuntimeException;
 use Tests\AbstractTestCase;
 
+#[Large]
 class FeaturesTest extends AbstractTestCase
 {
     /**
-     * @SuppressWarnings(PHPMD.LongVariable)
+     * @SuppressWarnings(LongVariable)
      */
-    protected $phpStanPreviousDirectory = '.';
+    protected string $phpStanPreviousDirectory = '.';
 
     protected function setUp(): void
     {
@@ -40,7 +42,7 @@ class FeaturesTest extends AbstractTestCase
     {
         $this->assertStringContainsString(
             '[OK] No errors',
-            $this->analyze(__DIR__.'/project.neon')
+            $this->analyze(__DIR__.'/project.neon'),
         );
     }
 
@@ -48,7 +50,7 @@ class FeaturesTest extends AbstractTestCase
     {
         $this->assertStringContainsString(
             '22     Static call to instance method Carbon\Carbon::foo().',
-            $this->analyze(__DIR__.'/bad-project.neon')
+            $this->analyze(__DIR__.'/bad-project.neon'),
         );
     }
 
